@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include <string.h>
 #include "argument.h"
 #include "charset.h"
-#include "other.h"
+#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -32,7 +32,7 @@
 	argv,
 	boot,TRUE:ưν
 	 RET,ե														*/
-gboolean *arg_analyse(gchar **argv,gboolean boot)
+gboolean *arg_analyse(gchar **argv,const gboolean boot)
 {
 	gboolean *arg_files;
 	gchar *arg,*text;
@@ -57,8 +57,7 @@ gboolean *arg_analyse(gchar **argv,gboolean boot)
 	{NULL,      0,  NULL,          NULL}};
 
 	for (i=0;argv[i]!=NULL;i++);
-	arg_files=g_malloc(i*sizeof(gboolean));
-	memset(arg_files,0,i*sizeof(gboolean));
+	arg_files=g_malloc0(i*sizeof(gboolean));
 	i=0;/* i:Υץ,j:iʸ,k:iʹߤarg */
 	while (argv[i]!=NULL)
 		if ((argv[i])[0]=='-') {/* ץ */
@@ -101,7 +100,7 @@ gboolean *arg_analyse(gchar **argv,gboolean boot)
 							charset_set(arg);
 						break;
 					case 'h':
-						strval(&history,arg,10,TRUE);
+						misc_str_to_val(&history,arg,10,TRUE);
 						if (history<0)
 							history=0;
 						else if (history>10)
@@ -120,7 +119,7 @@ gboolean *arg_analyse(gchar **argv,gboolean boot)
 						}
 						break;
 					case 'l':
-						strval(&init_line,arg,10,TRUE);
+						misc_str_to_val(&init_line,arg,10,TRUE);
 						break;
 					case 'n':
 						newfile=g_strcasecmp(arg,"OK")==0
@@ -133,9 +132,11 @@ gboolean *arg_analyse(gchar **argv,gboolean boot)
 						for (l=0;isdigit(text[l]);l++);
 						if (text[l]!='\0') {
 							text[l]='\0';
-							if (strval(&value,text,10,TRUE) && value>0)
+							if (misc_str_to_val(&value,text,10,TRUE)
+																	&& value>0)
 								def_width=value;
-							if (strval(&value,text+l+1,10,TRUE) && value>0)
+							if (misc_str_to_val(&value,text+l+1,10,TRUE)
+																	&& value>0)
 								def_height=value;
 						}
 						g_free(text);
@@ -150,7 +151,7 @@ gboolean *arg_analyse(gchar **argv,gboolean boot)
 						if (boot) {
 							g_print(
 "Text maid "VERSION"\n"
-"Copyright (C) 1998-2002 Iwamoto,Kazuki\n"
+"Copyright (C) 1998-2002 Kazuki IWAMOTO\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 							);
@@ -161,7 +162,7 @@ gboolean *arg_analyse(gchar **argv,gboolean boot)
 					default:
 						if (boot) {
 							g_print(
-"Copyright (c) 1998-2002 Iwamoto,Kazuki\n\n"
+"Copyright (c) 1998-2002 Kazuki IWAMOTO\n\n"
 "Usage: %s [OPTION...] [FILE...]\n\n",argv[0]);
 							for (i=0;arg_opts[i].name;i++) {
 								if (arg_opts[i].arg!=NULL)
