@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ static guchar space_gb2312[]=	{2,0xA1,0xA1,0};		/* λ */
 static guchar space_big5[]=		{2,0xA1,0x40,0};		/* λ */
 static guchar space_ksc5601[]=	{2,0xA1,0xA1,0};		/* ڹ */
 static guchar space_utf8[]=		{3,0xE3,0x80,0x80,0};	/* ISO-10646-1 */
-CHARSET charsetlist[]={
+static CharSet charset_list[]={
 {
 	"ascii,us-ascii,latin-1,iso-646,iso646,iso-8859,iso8859,iso-8859-1",
 	{	/*  0 1 2 3 4 5 6 7 8 9 A B C D E F 0 1 2 3 4 5 6 7 8 9 A B C D E F */
@@ -600,22 +600,22 @@ CHARSET charsetlist[]={
 	/* E */	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
 	NULL
 }};
-CHARSET *charset=charsetlist;
+CharSet *charset=charset_list;
 
 
-void charset_set(gchar *lang)
+void charset_set(const gchar *lang)
 {
-	gchar **charsetname;
+	gchar **charset_name;
 	gint i,j;
 
-	for (i=0;charsetlist[i].name!=NULL;i++) {
-		charsetname=g_strsplit(charsetlist[i].name,",",G_MAXINT);
-		for (j=0;charsetname[j]!=NULL;j++)
-			if (g_strcasecmp(lang,charsetname[j])==0) {
-				charset=charsetlist+i;
+	for (i=0;charset_list[i].name!=NULL;i++) {
+		charset_name=g_strsplit(charset_list[i].name,",",G_MAXINT);
+		for (j=0;charset_name[j]!=NULL;j++)
+			if (g_strcasecmp(lang,charset_name[j])==0) {
+				charset=charset_list+i;
 				break;
 			}
-		g_strfreev(charsetname);
+		g_strfreev(charset_name);
 	}
 }
 
