@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #include "find.h"
 #include "general.h"
 #include "jump.h"
-#include "other.h"
 #ifdef USE_GDKPIXBUF
 #include "print.h"
 #endif
@@ -33,6 +32,7 @@
 #include "repinfo.h"
 #include "signal.h"
 #include "valchr.h"
+#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -43,17 +43,17 @@
 void command_new(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	open_edit_file(NULL);
+	file_open_edit(NULL);
 }
 
 
-static gchar *command_open_file;
-
-
 static void command_open_ok(GtkWidget *widget,GtkWidget *dialog)
 {
-	command_open_file=g_strdup(gtk_file_selection_get_filename(
-												GTK_FILE_SELECTION(dialog)));
+	gchar **file;
+
+	file=gtk_object_get_user_data(GTK_OBJECT(dialog));
+	*file
+		=g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(dialog)));
     gtk_widget_destroy(dialog);
 }
 
@@ -61,9 +61,9 @@ static void command_open_ok(GtkWidget *widget,GtkWidget *dialog)
 void command_open(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
+	gchar *file=NULL;
 	GtkWidget *dialog;
 
-	command_open_file=NULL;
 	dialog=gtk_file_selection_new(_("Open"));
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
@@ -71,17 +71,18 @@ void command_open(gpointer callback_data,guint callback_action,
 	gtk_signal_connect_object(
 						GTK_OBJECT(GTK_FILE_SELECTION(dialog)->cancel_button),
 							"clicked",gtk_widget_destroy,GTK_OBJECT(dialog));
-	if (openpath!=NULL)
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog),openpath);
+	gtk_object_set_user_data(GTK_OBJECT(dialog),&file);
+	if (open_path!=NULL)
+		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog),open_path);
 	gtk_widget_show(dialog);
 	gtk_grab_add(dialog);
 	gtk_main();
-	if (command_open_file!=NULL) {
-		g_free(openpath);
-		openpath=get_full_path(command_open_file);
-		*g_basename(openpath)='\0';
-		open_edit_file(command_open_file);
-		g_free(command_open_file);
+	if (file!=NULL) {
+		g_free(open_path);
+		open_path=misc_get_full_path(file);
+		*g_basename(open_path)='\0';
+		file_open_edit(file);
+		g_free(file);
 	}
 }
 
@@ -90,22 +91,22 @@ void command_save(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gchar *text;
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	if (ptw->create) {
+	if (tmaid->create) {
 		command_saveas(callback_data,callback_action,widget);
 	} else {
 		text=g_strdup_printf(_("%s\nThis file is existed.\n\nOver write?"),
-																	ptw->file);
-		if ((!ptw->overwrite || !isfile(ptw->file)
-			|| message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
-											&& save_text_file(ptw->file,ptw)) {
-			ptw->edit=FALSE;
-			if (delete_list(&ptw->undo)+delete_list(&ptw->redo)>0)
-				set_menu_bar(ptw);
+																tmaid->file);
+		if ((!tmaid->overwrite || !misc_isfile(tmaid->file)
+			|| misc_message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
+										&& file_save_text(tmaid->file,tmaid)) {
+			tmaid->edit=FALSE;
+			if (delete_list(&tmaid->undo)+delete_list(&tmaid->redo)>0)
+				set_menu_bar(tmaid);
 		}
 	}
 }
@@ -114,14 +115,13 @@ void command_save(gpointer callback_data,guint callback_action,
 void command_saveas(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	gchar *text,*label;
-	TEXTWND *ptw;
+	gchar *text,*label,*file=NULL;
 	GtkWidget *dialog,*child;
+	TmaidWindow *tmaid;
 
 	child=gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 						gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)));
-	ptw=gtk_object_get_user_data(GTK_OBJECT(child));
-	command_open_file=NULL;
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(child));
 	dialog=gtk_file_selection_new(_("Save As"));
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
@@ -129,39 +129,40 @@ void command_saveas(gpointer callback_data,guint callback_action,
 	gtk_signal_connect_object(
 						GTK_OBJECT(GTK_FILE_SELECTION(dialog)->cancel_button),
 							"clicked",gtk_widget_destroy,GTK_OBJECT(dialog));
-	if (savepath!=NULL)
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog),savepath);
+	gtk_object_set_user_data(GTK_OBJECT(dialog),&file);
+	if (save_path!=NULL)
+		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog),save_path);
 	gtk_widget_show(dialog);
 	gtk_grab_add(dialog);
 	gtk_main();
-	if (command_open_file!=NULL) {
+	if (file!=NULL) {
 		text=g_strdup_printf(_("%s\nThis file is existed.\n\nOver write?"),
-															command_open_file);
-		if ((!ptw->overwrite || !isfile(command_open_file)
-			|| message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
-									&& save_text_file(command_open_file,ptw)) {
-			g_free(savepath);
-			savepath=get_full_path(command_open_file);
-			*g_basename(savepath)='\0';
+																		file);
+		if ((!tmaid->overwrite || !misc_isfile(file)
+			|| misc_message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
+											&& file_save_text(file,tmaid)) {
+			g_free(save_path);
+			save_path=misc_get_full_path(file);
+			*g_basename(save_path)='\0';
 			/* ե̾Ĵ٤ */
-			delete_edit_file(ptw->file);
-			ptw->file[0]='\0';
-			label=add_edit_file(command_open_file,&ptw->same);
-			gtk_label_set_text(GTK_LABEL(ptw->label),label);
+			file_delete_edit(tmaid->file);
+			tmaid->file[0]='\0';
+			label=file_add_edit(file,&tmaid->same);
+			gtk_label_set_text(GTK_LABEL(tmaid->label),label);
 			g_free(label);
 			/* ɥ˥塼 */
-			gtk_label_set_text(GTK_LABEL(GTK_BIN(ptw->menu_item)->child),
-															command_open_file);
+			gtk_label_set_text(GTK_LABEL(GTK_BIN(tmaid->menu_item)->child),
+																		file);
 			/*  */
-			ptw->create=ptw->edit=FALSE;
-			g_free(ptw->file);
-			ptw->file=g_strdup(command_open_file);
-			delete_list(&ptw->undo);
-			delete_list(&ptw->redo);
-			set_menu_bar(ptw);
-			set_history(ptw->file);
+			tmaid->create=tmaid->edit=FALSE;
+			g_free(tmaid->file);
+			tmaid->file=g_strdup(file);
+			delete_list(&tmaid->undo);
+			delete_list(&tmaid->redo);
+			set_menu_bar(tmaid);
+			file_set_history(tmaid->file);
 		}
-		g_free(command_open_file);
+		g_free(file);
 	}
 }
 
@@ -171,56 +172,56 @@ void command_reload(gpointer callback_data,guint callback_action,
 {
 	gchar *text;
 	gint result=0;
-	LINEBUF *p;
-	TEXTWND *ptw;
+	LineBuffer *p;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	if (ptw->edit) {
+	if (tmaid->edit) {
 		text=g_strdup_printf(
-				_("File %s was edited.\nRestore to existed file?"),ptw->file);
-		result=message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL);
+			_("File %s was edited.\nRestore to existed file?"),tmaid->file);
+		result=misc_message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL);
 		g_free(text);
 	}
 	if (result==0) {
 		/* Хåե */
-		while (ptw->start->prev!=NULL)
-			ptw->start=ptw->start->prev;
-		while (ptw->start!=NULL) {
-			p=ptw->start->next;
-			if (ptw->start->text!=NULL)
-				g_free(ptw->start->text);
-			g_free(ptw->start);
-			ptw->start=p;
+		while (tmaid->start->prev!=NULL)
+			tmaid->start=tmaid->start->prev;
+		while (tmaid->start!=NULL) {
+			p=tmaid->start->next;
+			if (tmaid->start->text!=NULL)
+				g_free(tmaid->start->text);
+			g_free(tmaid->start);
+			tmaid->start=p;
 		}
-		delete_list(&ptw->undo);
-		delete_list(&ptw->redo);
+		delete_list(&tmaid->undo);
+		delete_list(&tmaid->redo);
 		/* ɤ߹ */
-		open_text_file(ptw);
-		if (ptw->start==NULL) {
+		file_open_text(tmaid);
+		if (tmaid->start==NULL) {
 			/* ե뤬0ХȤΤȤ */
-			ptw->off=0;
-			ptw->max=1;
-			ptw->start=g_malloc(sizeof(LINEBUF));
-			ptw->start->length=0;
-			ptw->start->margin=FALSE;
-			ptw->start->text=NULL;
-			ptw->start->prev=ptw->start->next=NULL;
+			tmaid->off=0;
+			tmaid->max=1;
+			tmaid->start=g_malloc(sizeof(LineBuffer));
+			tmaid->start->length=0;
+			tmaid->start->margin=FALSE;
+			tmaid->start->text=NULL;
+			tmaid->start->prev=tmaid->start->next=NULL;
 		}
-		ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
-		ptw->edit=FALSE;
-		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-					0,get_width_max(ptw)+1,
-					MAX(ptw->drawing->allocation.width/ptw->fontwidth,1),
-																ptw->top.x);
-		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-					0,ptw->max,
-					MAX(ptw->drawing->allocation.height/(ptw->fontheight),1),
-																ptw->top.y);
-		set_menu_bar(ptw);
-		draw_caret(ptw,NULL);
-		gtk_widget_draw(ptw->drawing,NULL);
+		tmaid->cursor.x=tmaid->cursor.y=tmaid->top.x=tmaid->top.y=0;
+		tmaid->edit=FALSE;
+		misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
+					0,edit_get_width_max(tmaid)+1,
+					MAX(tmaid->drawing->allocation.width/tmaid->font_width,1),
+																tmaid->top.x);
+		misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
+				0,tmaid->max,
+				MAX(tmaid->drawing->allocation.height/(tmaid->font_height),1),
+																tmaid->top.y);
+		set_menu_bar(tmaid);
+		draw_caret(tmaid,NULL);
+		gtk_widget_draw(tmaid->drawing,NULL);
 	}
 }
 
@@ -229,17 +230,17 @@ void command_reload(gpointer callback_data,guint callback_action,
 void command_print(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	printer.select=ptw->select.x>=0;
-	printer.column=ptw->margin;
-	printer.fontwidth=ptw->fontwidth;
-	printer.fontheight=ptw->fontheight;
+	printer.select=tmaid->select.x>=0;
+	printer.column=tmaid->margin;
+	printer.font_width=tmaid->font_width;
+	printer.font_height=tmaid->font_height;
 	if (print_dialog(&printer))
-		print_out(ptw,&printer);
+		print_out(tmaid,&printer);
 }
 #endif
 
@@ -248,37 +249,37 @@ void command_property(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gint i;
-	FTYPE ft;
 	GList *glist;
-	TEXTWND *ptw;
+	FileType ft;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	ft.ft_id=ptw->ft_id;
-	ft.margin=ptw->margin;
-	ft.tab=ptw->tab;
-	ft.autoindent=ptw->autoindent;
-	ft.crlf=ptw->crlf;
-	ft.eof=ptw->eof;
-	ft.limit=ptw->limit;
-	ft.overwrite=ptw->overwrite;
-	ft.space=ptw->space;
-	ft.syscol=ptw->syscol;
-	ft.gline=ptw->gline;
-	ft.mline=ptw->mline;
-	ft.uline=ptw->uline;
-	ft.vline=ptw->vline;
-	ft.fontname=g_strdup(ptw->fontname);
-	memcpy(ft.color,ptw->color,sizeof(GdkColor)*12);
+	ft.ft_id=tmaid->ft_id;
+	ft.margin=tmaid->margin;
+	ft.tab=tmaid->tab;
+	ft.autoindent=tmaid->autoindent;
+	ft.crlf=tmaid->crlf;
+	ft.eof=tmaid->eof;
+	ft.limit=tmaid->limit;
+	ft.overwrite=tmaid->overwrite;
+	ft.space=tmaid->space;
+	ft.syscol=tmaid->syscol;
+	ft.gline=tmaid->gline;
+	ft.mline=tmaid->mline;
+	ft.uline=tmaid->uline;
+	ft.vline=tmaid->vline;
+	ft.font_name=g_strdup(tmaid->font_name);
+	memcpy(ft.color,tmaid->color,sizeof(GdkColor)*12);
 	ft.text=ft.ext=NULL;
 	if (property_dialog(&ft)) {
 		if (ft.ft_id<0) {
 			/* ̵°ΤȤˤϤΥɥѹ */
-			change_property(ptw,&ft);
+			property_change(tmaid,&ft);
 		} else {
 			/* Ʊե륿פ򤹤٤ѹ */
-			ptw->ft_id=ft.ft_id;
+			tmaid->ft_id=ft.ft_id;
 			for (i=0;i<ftnum;i++)
 				if (ftype[i].ft_id==ft.ft_id) {
 					ftype[i].margin=ft.margin;
@@ -295,22 +296,22 @@ void command_property(gpointer callback_data,guint callback_action,
 					ftype[i].mline=ft.mline;
 					ftype[i].uline=ft.uline;
 					ftype[i].vline=ft.vline;
-					g_free(ftype[i].fontname);
-					ftype[i].fontname=g_strdup(ft.fontname);
+					g_free(ftype[i].font_name);
+					ftype[i].font_name=g_strdup(ft.font_name);
 					memcpy(ftype[i].color,ft.color,sizeof(GdkColor)*12);
 					break;
 				}
 			glist=gtk_container_children(GTK_CONTAINER(notebook));
 			for (i=g_list_length(glist)-1;i>=0;i--) {
-				ptw=gtk_object_get_user_data(
+				tmaid=gtk_object_get_user_data(
 										GTK_OBJECT(g_list_nth_data(glist,i)));
-				if (ptw->ft_id==ft.ft_id)
-					change_property(ptw,&ft);
+				if (tmaid->ft_id==ft.ft_id)
+					property_change(tmaid,&ft);
 			}
 			g_list_free(glist);
 		}
 	}
-	g_free(ft.fontname);
+	g_free(ft.font_name);
 }
 
 
@@ -318,12 +319,12 @@ void command_close(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gint page;
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
 	if ((page=gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))>=0) {
-		ptw=gtk_object_get_user_data(GTK_OBJECT(
+		tmaid=gtk_object_get_user_data(GTK_OBJECT(
 					gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),page)));
-		if (prompt_close(ptw))
+		if (prompt_close(tmaid))
 			gtk_notebook_remove_page(GTK_NOTEBOOK(notebook),page);
 	}
 }
@@ -344,24 +345,24 @@ void command_exit(gpointer callback_data,guint callback_action,
 void command_undo(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	history_operation(ptw,FALSE);
+	history_operation(tmaid,FALSE);
 }
 
 
 void command_redo(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	history_operation(ptw,TRUE);
+	history_operation(tmaid,TRUE);
 }
 
 
@@ -377,16 +378,16 @@ void command_copy(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gint length;
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
 	if (gtk_selection_owner_set(window,atom_clipboard,GDK_CURRENT_TIME)) {
-		ptw=gtk_object_get_user_data(GTK_OBJECT(
+		tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 		g_free(clipboard_text);
-		length=get_sel_bytes(ptw,&ptw->select,&ptw->cursor);
+		length=edit_get_sel_bytes(tmaid,&tmaid->select,&tmaid->cursor);
 		clipboard_text=g_malloc((length+1)*sizeof(gchar));
-		cpy_sel_mem(ptw,&ptw->select,&ptw->cursor,clipboard_text);
+		edit_cpy_sel_mem(tmaid,&tmaid->select,&tmaid->cursor,clipboard_text);
 		clipboard_text[length]='\0';
 	}
 }
@@ -402,31 +403,31 @@ void command_paste(gpointer callback_data,guint callback_action,
 void command_delete(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	DOING *d;
-	TEXTWND *ptw;
+	TmaidHistory *d;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	d=edit_operation(ptw,NULL,0,TRUE,FALSE);
-	d->next=ptw->undo;
-	ptw->undo=d;
-	set_menu_bar(ptw);
-	ptw->edit=TRUE;
+	d=edit_operation(tmaid,NULL,0,TRUE,FALSE);
+	d->next=tmaid->undo;
+	tmaid->undo=d;
+	set_menu_bar(tmaid);
+	tmaid->edit=TRUE;
 }
 
 
 void command_margin(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
-	if (message_box("Text maid",_("Return at Right Margin?"),1,
+	if (misc_message_box("Text maid",_("Return at Right Margin?"),1,
 												_("_Yes"),_("_No"),NULL)==0) {
-		ptw=gtk_object_get_user_data(GTK_OBJECT(
+		tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-		margin_operation(ptw);
+		margin_operation(tmaid);
 	}
 }
 
@@ -434,14 +435,14 @@ void command_margin(gpointer callback_data,guint callback_action,
 void command_tab(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
-	if (message_box("Text maid",_("Convert Tab to Space?"),1,
+	if (misc_message_box("Text maid",_("Convert Tab to Space?"),1,
 												_("_Yes"),_("_No"),NULL)==0) {
-		ptw=gtk_object_get_user_data(GTK_OBJECT(
+		tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-		tab_operation(ptw);
+		tab_operation(tmaid);
 	}
 }
 
@@ -450,21 +451,21 @@ void command_valchr(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gchar valchr;
-	DOING *d;
-	TEXTWND *ptw;
+	TmaidHistory *d;
+	TmaidWindow *tmaid;
 	GdkPoint select;
 
 	if (valchr_dialog(&valchr)) {
-		ptw=gtk_object_get_user_data(GTK_OBJECT(
+		tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-		select=ptw->select;
-		d=edit_operation(ptw,&valchr,1,TRUE,FALSE);
-		d->next=ptw->undo;
-		ptw->undo=d;
-		if (delete_list(&ptw->redo)>0 || d->next==NULL || select.x>=0)
-			set_menu_bar(ptw);
-		ptw->edit=TRUE;
+		select=tmaid->select;
+		d=edit_operation(tmaid,&valchr,1,TRUE,FALSE);
+		d->next=tmaid->undo;
+		tmaid->undo=d;
+		if (delete_list(&tmaid->redo)>0 || d->next==NULL || select.x>=0)
+			set_menu_bar(tmaid);
+		tmaid->edit=TRUE;
 	}
 }
 
@@ -472,16 +473,16 @@ void command_valchr(gpointer callback_data,guint callback_action,
 void command_jump(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	JMPDLG jmp;
-	TEXTWND *ptw;
+	JumpDialog jmp;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	jmp.max=ptw->max;
-	jmp.cursor=ptw->cursor.y+1;
-	if (jump_dialog(&jmp) && ptw->cursor.y!=jmp.cursor-1)
-		jump_operation(ptw,jmp.cursor);
+	jmp.max=tmaid->max;
+	jmp.cursor=tmaid->cursor.y+1;
+	if (jump_dialog(&jmp) && tmaid->cursor.y!=jmp.cursor-1)
+		jump_operation(tmaid,jmp.cursor);
 }
 
 
@@ -490,36 +491,36 @@ void command_all(gpointer callback_data,guint callback_action,
 {
 	gint sx,sy;
 	GdkPoint top;
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	if (ptw->max<=1 && ptw->start->length<=0)
+	if (tmaid->max<=1 && tmaid->start->length<=0)
 		return;
-	top=ptw->top;
-	sx=MAX(ptw->drawing->allocation.width/ptw->fontwidth,1);
-	sy=MAX(ptw->drawing->allocation.height/ptw->fontheight,1);
-	if (ptw->select.x<0)/* 򤹤 */
+	top=tmaid->top;
+	sx=MAX(tmaid->drawing->allocation.width/tmaid->font_width,1);
+	sy=MAX(tmaid->drawing->allocation.height/tmaid->font_height,1);
+	if (tmaid->select.x<0)/* 򤹤 */
 		gtk_selection_owner_set(window,GDK_SELECTION_PRIMARY,GDK_CURRENT_TIME);
-	ptw->select.x=ptw->select.y=0;
-	ptw->cursor.x=get_width(ptw,ptw->cursor.y=ptw->max-1);
-	if (ptw->cursor.x<ptw->top.x)
-		ptw->top.x=ptw->cursor.x;
-	else if (ptw->cursor.x-sx+1>ptw->top.x)
-		ptw->top.x=ptw->cursor.x-sx+1;
-	if (ptw->cursor.y<ptw->top.y)
-		ptw->top.y=ptw->cursor.y;
-	else if (ptw->cursor.y-sy+1>ptw->top.y)
-		ptw->top.y=ptw->cursor.y-sy+1;
-	set_menu_bar(ptw);
-	if (ptw->top.x!=top.x)
-		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw)+1,sx,ptw->top.x);
-	if (ptw->top.y!=top.y)
-		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max,sy,ptw->top.y);
-	gtk_widget_draw(ptw->drawing,NULL);
+	tmaid->select.x=tmaid->select.y=0;
+	tmaid->cursor.x=edit_get_width(tmaid,tmaid->cursor.y=tmaid->max-1);
+	if (tmaid->cursor.x<tmaid->top.x)
+		tmaid->top.x=tmaid->cursor.x;
+	else if (tmaid->cursor.x-sx+1>tmaid->top.x)
+		tmaid->top.x=tmaid->cursor.x-sx+1;
+	if (tmaid->cursor.y<tmaid->top.y)
+		tmaid->top.y=tmaid->cursor.y;
+	else if (tmaid->cursor.y-sy+1>tmaid->top.y)
+		tmaid->top.y=tmaid->cursor.y-sy+1;
+	set_menu_bar(tmaid);
+	if (tmaid->top.x!=top.x)
+		misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
+								0,edit_get_width_max(tmaid)+1,sx,tmaid->top.x);
+	if (tmaid->top.y!=top.y)
+		misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
+								0,tmaid->max,sy,tmaid->top.y);
+	gtk_widget_draw(tmaid->drawing,NULL);
 }
 
 
@@ -528,24 +529,25 @@ void command_find(gpointer callback_data,guint callback_action,
 {
 	gchar *text;
 	gint i;
-	FIND fd;
-	TEXTWND *ptw;
+	FindString fd;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 	fd.text=NULL;
 	fd.arrow=find_arrow;
 	fd.ignorecase=find_ignorecase;
-	if (ptw->select.x>=0) {
-		if (ptw->select.y<ptw->cursor.y
-			|| (ptw->select.y==ptw->cursor.y && ptw->select.x<ptw->cursor.x))
+	if (tmaid->select.x>=0) {
+		if (tmaid->select.y<tmaid->cursor.y
+										|| (tmaid->select.y==tmaid->cursor.y
+										&& tmaid->select.x<tmaid->cursor.x))
 				fd.arrow=FALSE;
 			else
 				fd.arrow=TRUE;
 	}
 	if (find_dialog(&fd)) {
-		set_menu_bar(ptw);
+		set_menu_bar(tmaid);
 		find_arrow=fd.arrow;
 		find_ignorecase=fd.ignorecase;
 		for (i=0;i<find_num;i++)
@@ -575,18 +577,18 @@ void command_next(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gchar *text;
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	find_operation(ptw,&ptw->cursor,&ptw->select,find_text[0],
+	find_operation(tmaid,&tmaid->cursor,&tmaid->select,find_text[0],
 					callback_action==0?find_arrow:!find_arrow,find_ignorecase);
-	if (userbreak && ptw->select.x<0) {
+	if (userbreak && tmaid->select.x<0) {
 		text=g_strdup_printf(_("'%s' was not fount."),find_text[0]);
-		message_box("Text maid",text,0,_("OK"),NULL);
+		misc_message_box("Text maid",text,0,_("OK"),NULL);
 		g_free(text);
-		set_menu_bar(ptw);
+		set_menu_bar(tmaid);
 	}
 }
 
@@ -596,29 +598,30 @@ void command_replace(gpointer callback_data,guint callback_action,
 {
 	gboolean replace=FALSE;
 	gchar *text;
-	gint i,bytes,count=0,datapos,result;
-	DOING *d;
-	TEXTWND *ptw;
-	REPINFO ri;
-	REPLACE rp;
+	gint i,bytes,count=0,data_pos,result;
 	GdkPoint select;
+	TmaidHistory *d;
+	TmaidWindow *tmaid;
+	ReplaceInfo ri;
+	ReplaceString rp;
 
-	ptw=gtk_object_get_user_data(GTK_OBJECT(
+	tmaid=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 	rp.src=rp.dst=NULL;
 	rp.arrow=replace_arrow;
 	rp.ignorecase=replace_ignorecase;
-	if (ptw->select.x>=0) {
-		if (ptw->select.y<ptw->cursor.y
-			|| (ptw->select.y==ptw->cursor.y && ptw->select.x<ptw->cursor.x))
+	if (tmaid->select.x>=0) {
+		if (tmaid->select.y<tmaid->cursor.y
+										|| (tmaid->select.y==tmaid->cursor.y
+										&& tmaid->select.x<tmaid->cursor.x))
 				rp.arrow=FALSE;
 			else
 				rp.arrow=TRUE;
 	}
 	result=replace_dialog(&rp);
-	if (result>=0) {
-		set_menu_bar(ptw);
+	if (result!=REPLACE_CANCEL) {
+		set_menu_bar(tmaid);
 		replace_arrow=rp.arrow;
 		replace_ignorecase=rp.ignorecase;
 		for (i=0;i<find_num;i++)
@@ -656,54 +659,54 @@ void command_replace(gpointer callback_data,guint callback_action,
 				replace_text[0]=text;
 			}
 		}
-		select=ptw->select;
+		select=tmaid->select;
 		ri.arrow=replace_arrow;
 		ri.ignorecase=replace_ignorecase;
 		ri.dst=replace_text[0];
 		do {
-			find_operation(ptw,&ptw->cursor,&select,find_text[0],
+			find_operation(tmaid,&tmaid->cursor,&select,find_text[0],
 											replace_arrow,replace_ignorecase);
-			if (ptw->select.x<0)
+			if (tmaid->select.x<0)
 				break;
 			replace=TRUE;
-			bytes=get_sel_bytes(ptw,&ptw->select,&ptw->cursor);
-			if (result<=1) {
+			bytes=edit_get_sel_bytes(tmaid,&tmaid->select,&tmaid->cursor);
+			if (result!=REPLACE_ALL) {
 				ri.src=g_malloc(bytes+1);
-				cpy_sel_mem(ptw,&ptw->select,&ptw->cursor,ri.src);
+				edit_cpy_sel_mem(tmaid,&tmaid->select,&tmaid->cursor,ri.src);
 				ri.src[bytes]='\0';
-				ri.start=ptw->select;
-				ri.end=ptw->cursor;
+				ri.start=tmaid->select;
+				ri.end=tmaid->cursor;
 				result=repinfo_dialog(&ri);
 				g_free(ri.src);
-				if (result<=0)
+				if (result==REPLACE_CANCEL || result==REPLACE_NEXT)
 					continue;
 			}
-			if (select.x>=0 && ptw->cursor.y==select.y && replace_arrow)
-				datapos=get_data_pos(ptw,select.x,select.y,FALSE);
+			if (select.x>=0 && tmaid->cursor.y==select.y && replace_arrow)
+				data_pos=edit_get_data_pos(tmaid,select.x,select.y,FALSE);
 			else
-				datapos=-1;
-			d=edit_operation(ptw,replace_text[0],strlen(replace_text[0]),
+				data_pos=-1;
+			d=edit_operation(tmaid,replace_text[0],strlen(replace_text[0]),
 														replace_arrow,TRUE);
-			if (datapos>=0)
-				select.x=get_screen_pos(ptw,
-										datapos+strlen(rp.dst)-bytes,select.y);
-			if (result>1)
+			if (data_pos>=0)
+				select.x=edit_get_screen_pos(tmaid,
+									data_pos+strlen(rp.dst)-bytes,select.y);
+			if (result==REPLACE_OK || result==REPLACE_ALL)
 				count++;
-			d->next=ptw->undo;
-			ptw->undo=d;
-			if (delete_list(&ptw->redo)>0 || d->next==NULL)
-				set_menu_bar(ptw);
-			ptw->edit=TRUE;
-		} while (result>=0);
+			d->next=tmaid->undo;
+			tmaid->undo=d;
+			if (delete_list(&tmaid->redo)>0 || d->next==NULL)
+				set_menu_bar(tmaid);
+			tmaid->edit=TRUE;
+		} while (result!=REPLACE_CANCEL);
 		if (!replace) {
 			text=g_strdup_printf(_("'%s' was not fount."),find_text[0]);
-			message_box("Text maid",text,0,_("OK"),NULL);
+			misc_message_box("Text maid",text,0,_("OK"),NULL);
 			g_free(text);
 		} else if (result>1) {
 			text=g_strdup_printf(_("%d strings were replaced"),count);
-			message_box("Text maid",text,0,_("OK"),NULL);
+			misc_message_box("Text maid",text,0,_("OK"),NULL);
 			g_free(text);
 		}
-		set_menu_bar(ptw);
+		set_menu_bar(tmaid);
 	}
 }
