@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 #include "abort.h"
 #include "charset.h"
 #include "file.h"
-#include "other.h"
 #include "signal.h"
+#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -32,7 +32,7 @@
 ******************************************************************************/
 /*	ե˲ä
 	file,ե̾															*/
-void set_history(gchar *file)
+void file_set_history(const gchar *file)
 {
 	gchar *label;
 	gint i,count;
@@ -78,13 +78,13 @@ void set_history(gchar *file)
 	file,ä褦ȤեΥեѥ
 	same,եѥ°
 	 RET,ä褦ȤեΥ٥										*/
-gchar *add_edit_file(gchar *file,gint *same)
+gchar *file_add_edit(const gchar *file,gint *same)
 {
 	gchar *label,*name0,*name1;
 	gint i;
 	GList *glist;
-	TEXTWND *ptw;
 	GtkWidget *child;
+	TmaidWindow *tmaid;
 
 	*same=-1;
 	/* ե̾Ĵ٤ */
@@ -92,16 +92,16 @@ gchar *add_edit_file(gchar *file,gint *same)
 	/* Ʊ̾ƱѥĴ٤ */
 	for (i=g_list_length(glist)-1;i>=0;i--) {
 		child=g_list_nth_data(glist,i);
-		ptw=gtk_object_get_user_data(GTK_OBJECT(child));
-		if (strcmp(file,ptw->file)==0) {
-			if (ptw->same<0) {
-				ptw->same=0;
-				label=g_strdup_printf("%s:%d",ptw->file,ptw->same);
-				gtk_label_set_text(GTK_LABEL(ptw->label),label);
+		tmaid=gtk_object_get_user_data(GTK_OBJECT(child));
+		if (strcmp(file,tmaid->file)==0) {
+			if (tmaid->same<0) {
+				tmaid->same=0;
+				label=g_strdup_printf("%s:%d",tmaid->file,tmaid->same);
+				gtk_label_set_text(GTK_LABEL(tmaid->label),label);
 				g_free(label);
 			}
-			if (*same<=ptw->same)
-				*same=ptw->same+1;
+			if (*same<=tmaid->same)
+				*same=tmaid->same+1;
 		}
 	}
 	if (*same>=0) {
@@ -113,11 +113,11 @@ gchar *add_edit_file(gchar *file,gint *same)
 		name0=g_basename(file);
 		for (i=g_list_length(glist)-1;i>=0;i--) {
 			child=g_list_nth_data(glist,i);
-			ptw=gtk_object_get_user_data(GTK_OBJECT(child));
-			name1=g_basename(ptw->file);
+			tmaid=gtk_object_get_user_data(GTK_OBJECT(child));
+			name1=g_basename(tmaid->file);
 			if (strcmp(name0,name1)==0) {
-				if (ptw->same<0)
-					gtk_label_set_text(GTK_LABEL(ptw->label),ptw->file);
+				if (tmaid->same<0)
+					gtk_label_set_text(GTK_LABEL(tmaid->label),tmaid->file);
 				break;
 			}
 		}
@@ -130,12 +130,12 @@ gchar *add_edit_file(gchar *file,gint *same)
 
 /*	ե
 	file,褦ȤեΥեѥ									*/
-void delete_edit_file(gchar *file)
+void file_delete_edit(const gchar *file)
 {
 	gchar *name0,*name1;
 	gint i,count=0;
 	GList *glist;
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 	GtkWidget *child;
 
 	/* ե̾Ĵ٤ */
@@ -143,8 +143,8 @@ void delete_edit_file(gchar *file)
 	/* Ʊ̾ۥѥĴ٤ */
 	name0=g_basename(file);
 	for (i=g_list_length(glist)-1;i>=0;i--) {
-		ptw=gtk_object_get_user_data(g_list_nth_data(glist,i));
-		name1=g_basename(ptw->file);
+		tmaid=gtk_object_get_user_data(g_list_nth_data(glist,i));
+		name1=g_basename(tmaid->file);
 		if (strcmp(name0,name1)==0)
 			count++;
 	}
@@ -152,26 +152,26 @@ void delete_edit_file(gchar *file)
 		/* Ʊ̾ۥѥΥե̾ɽѹ */
 		for (i=g_list_length(glist)-1;i>=0;i--) {
 			child=g_list_nth_data(glist,i);
-			ptw=gtk_object_get_user_data(GTK_OBJECT(child));
-			name1=g_basename(ptw->file);
+			tmaid=gtk_object_get_user_data(GTK_OBJECT(child));
+			name1=g_basename(tmaid->file);
 			if (strcmp(name0,name1)==0)
-				gtk_label_set_text(GTK_LABEL(ptw->label),name1);
+				gtk_label_set_text(GTK_LABEL(tmaid->label),name1);
 		}
 	} else {
 		/* Ʊ̾ƱѥĴ٤ */
 		count=0;
 		for (i=g_list_length(glist)-1;i>=0;i--) {
-			ptw=gtk_object_get_user_data(g_list_nth_data(glist,i));
-			if (strcmp(file,ptw->file)==0)
+			tmaid=gtk_object_get_user_data(g_list_nth_data(glist,i));
+			if (strcmp(file,tmaid->file)==0)
 				count++;
 		}
 		if (count<=2)/* Ʊ̾ƱѥΥեեѥɽѹ */
 			for (i=g_list_length(glist)-1;i>=0;i--) {
 				child=g_list_nth_data(glist,i);
-				ptw=gtk_object_get_user_data(GTK_OBJECT(child));
-				if (strcmp(file,ptw->file)==0) {
-					ptw->same=-1;
-					gtk_label_set_text(GTK_LABEL(ptw->label),ptw->file);
+				tmaid=gtk_object_get_user_data(GTK_OBJECT(child));
+				if (strcmp(file,tmaid->file)==0) {
+					tmaid->same=-1;
+					gtk_label_set_text(GTK_LABEL(tmaid->label),tmaid->file);
 				}
 			}
 	}
@@ -184,24 +184,24 @@ void delete_edit_file(gchar *file)
 *                                                                             *
 ******************************************************************************/
 /*	TXTե򳫤
-	ptw,TXTɥ													*/
-void open_text_file(TEXTWND *ptw)
+	tmaid,TXTɥ													*/
+void file_open_text(TmaidWindow *tmaid)
 {
 	int c;
 	FILE *fp;
-	LINEBUF *p,*q;
+	LineBuffer *p,*q;
 	GtkWidget *dialog;
 
-	if ((fp=fopen(ptw->file,"rt"))==NULL)
+	if ((fp=fopen(tmaid->file,"rt"))==NULL)
 		return;
-	p=g_malloc(sizeof(LINEBUF));
+	p=g_malloc(sizeof(LineBuffer));
 	p->length=0;
 	p->margin=FALSE;
 	p->text=NULL;
 	p->prev=p->next=NULL;
-	ptw->max=1;
-	ptw->off=0;
-	ptw->start=p;
+	tmaid->max=1;
+	tmaid->off=0;
+	tmaid->start=p;
 	/* ܥå */
 	userbreak=TRUE;
 	dialog=abort_dialog(_("Reading"));
@@ -210,7 +210,7 @@ void open_text_file(TEXTWND *ptw)
 		while (gtk_events_pending())
 			gtk_main_iteration();
 		if (c=='\n') {
-			q=g_malloc(sizeof(LINEBUF));
+			q=g_malloc(sizeof(LineBuffer));
 			q->text=NULL;
 			q->length=0;
 			q->margin=FALSE;
@@ -218,7 +218,7 @@ void open_text_file(TEXTWND *ptw)
 			q->next=p->next;
 			p->next=q;
 			p=q;
-			ptw->max++;
+			tmaid->max++;
 		} else {
 			p->text=g_realloc(p->text,(p->length+1)*sizeof(gchar));
 			p->text[p->length++]=c;
@@ -234,11 +234,11 @@ void open_text_file(TEXTWND *ptw)
 /*	ե򳫤
 	file,ե̾
 	 RET,TXTɥ													*/
-TEXTWND *open_edit_file(gchar *file)
+TmaidWindow *file_open_edit(const gchar *file)
 {
 	gchar *ext,*p,*text;
 	gint i,leng0,leng1;
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
 	GtkWidget *table,*sub_menu,*button,*frame,*hbox;
@@ -255,48 +255,48 @@ TEXTWND *open_edit_file(gchar *file)
 " ..  .. ",
 "..    .."};
 
-	ptw=g_malloc(sizeof(TEXTWND));
-	ptw->same=-1;
-	ptw->edit=FALSE;
-	ptw->start=NULL;
-	ptw->undo=ptw->redo=NULL;
-	ptw->top.x=ptw->top.y=ptw->cursor.x=ptw->cursor.y=0;
-	ptw->select.x=-1;
-	ptw->timer_id=0;
-	ptw->ic=NULL;
-	ptw->ic_attr=NULL;
+	tmaid=g_malloc(sizeof(TmaidWindow));
+	tmaid->same=-1;
+	tmaid->edit=FALSE;
+	tmaid->start=NULL;
+	tmaid->undo=tmaid->redo=NULL;
+	tmaid->top.x=tmaid->top.y=tmaid->cursor.x=tmaid->cursor.y=0;
+	tmaid->select.x=-1;
+	tmaid->timer_id=0;
+	tmaid->ic=NULL;
+	tmaid->ic_attr=NULL;
 	if (file==NULL) {
 		/*  */
-		ptw->file=g_strdup_printf("new%04d",fcount++%1000);
-		ptw->create=TRUE;
+		tmaid->file=g_strdup_printf("new%04d",fcount++%1000);
+		tmaid->create=TRUE;
 		i=0;
-		ptw->ft_id=ftype[0].associate?ftype[0].ft_id:-1;
-		ptw->margin=ftype[0].margin;
-		ptw->tab=ftype[0].tab;
-		ptw->autoindent=ftype[0].autoindent;
-		ptw->code=ftype[0].code;
-		ptw->crlf=ftype[0].crlf;
-		ptw->eof=ftype[0].eof;
-		ptw->limit=ftype[0].limit;
-		ptw->overwrite=ftype[0].overwrite;
-		ptw->space=ftype[0].space;
-		ptw->syscol=ftype[0].syscol;
-		ptw->gline=ftype[0].gline;
-		ptw->mline=ftype[0].mline;
-		ptw->uline=ftype[0].uline;
-		ptw->vline=ftype[0].vline;
-		ptw->fontname=g_strdup(ftype[0].fontname);
-		memcpy(ptw->color,ftype[0].color,sizeof(GdkColor)*12);
+		tmaid->ft_id=ftype[0].associate?ftype[0].ft_id:-1;
+		tmaid->margin=ftype[0].margin;
+		tmaid->tab=ftype[0].tab;
+		tmaid->autoindent=ftype[0].autoindent;
+		tmaid->code=ftype[0].code;
+		tmaid->crlf=ftype[0].crlf;
+		tmaid->eof=ftype[0].eof;
+		tmaid->limit=ftype[0].limit;
+		tmaid->overwrite=ftype[0].overwrite;
+		tmaid->space=ftype[0].space;
+		tmaid->syscol=ftype[0].syscol;
+		tmaid->gline=ftype[0].gline;
+		tmaid->mline=ftype[0].mline;
+		tmaid->uline=ftype[0].uline;
+		tmaid->vline=ftype[0].vline;
+		tmaid->font_name=g_strdup(ftype[0].font_name);
+		memcpy(tmaid->color,ftype[0].color,sizeof(GdkColor)*12);
 	} else {
-		ptw->file=get_full_path(file);
-		leng0=strlen(ptw->file);
+		tmaid->file=misc_get_full_path(file);
+		leng0=strlen(tmaid->file);
 		for (i=0;i<ftnum;i++) {
 			if (strcmp(ftype[i].ext,"*")==0)
 				break;
 			ext=g_strdup(ftype[i].ext);
 			for (p=strtok(ext,";");p!=NULL;p=strtok(NULL,";")) {
 				leng1=strlen(p);
-				if (leng0>=leng1 && strcmp(ptw->file+leng0-leng1,p)==0)
+				if (leng0>=leng1 && strcmp(tmaid->file+leng0-leng1,p)==0)
 					goto loop;
 			}
 			g_free(ext);
@@ -304,101 +304,102 @@ TEXTWND *open_edit_file(gchar *file)
 		loop:
 		if (i>=ftnum)
 			i=0;
-		ptw->create=FALSE;
-		ptw->ft_id=ftype[i].associate?ftype[i].ft_id:-1;
-		ptw->margin=ftype[i].margin;
-		ptw->tab=ftype[i].tab;
-		ptw->autoindent=ftype[i].autoindent;
-		ptw->code=ftype[i].code;
-		ptw->crlf=ftype[i].crlf;
-		ptw->eof=ftype[i].eof;
-		ptw->limit=ftype[i].limit;
-		ptw->overwrite=ftype[i].overwrite;
-		ptw->space=ftype[i].space;
-		ptw->syscol=ftype[i].syscol;
-		ptw->gline=ftype[i].gline;
-		ptw->mline=ftype[i].mline;
-		ptw->uline=ftype[i].uline;
-		ptw->vline=ftype[i].vline;
-		ptw->fontname=g_strdup(ftype[i].fontname);
-		memcpy(ptw->color,ftype[i].color,sizeof(GdkColor)*12);
-		open_text_file(ptw);
+		tmaid->create=FALSE;
+		tmaid->ft_id=ftype[i].associate?ftype[i].ft_id:-1;
+		tmaid->margin=ftype[i].margin;
+		tmaid->tab=ftype[i].tab;
+		tmaid->autoindent=ftype[i].autoindent;
+		tmaid->code=ftype[i].code;
+		tmaid->crlf=ftype[i].crlf;
+		tmaid->eof=ftype[i].eof;
+		tmaid->limit=ftype[i].limit;
+		tmaid->overwrite=ftype[i].overwrite;
+		tmaid->space=ftype[i].space;
+		tmaid->syscol=ftype[i].syscol;
+		tmaid->gline=ftype[i].gline;
+		tmaid->mline=ftype[i].mline;
+		tmaid->uline=ftype[i].uline;
+		tmaid->vline=ftype[i].vline;
+		tmaid->font_name=g_strdup(ftype[i].font_name);
+		memcpy(tmaid->color,ftype[i].color,sizeof(GdkColor)*12);
+		file_open_text(tmaid);
 	}
-	if (ptw->start==NULL) {
+	if (tmaid->start==NULL) {
 		/* ե뤬0ХȤΤȤ */
-		ptw->off=0;
-		ptw->max=1;
-		ptw->start=g_malloc(sizeof(LINEBUF));
-		ptw->start->length=0;
-		ptw->start->margin=FALSE;
-		ptw->start->text=NULL;
-		ptw->start->prev=ptw->start->next=NULL;
+		tmaid->off=0;
+		tmaid->max=1;
+		tmaid->start=g_malloc(sizeof(LineBuffer));
+		tmaid->start->length=0;
+		tmaid->start->margin=FALSE;
+		tmaid->start->text=NULL;
+		tmaid->start->prev=tmaid->start->next=NULL;
 	}
 
 	/* ե̾Ĵ٤ */
-	text=add_edit_file(ptw->file,&ptw->same);
+	text=file_add_edit(tmaid->file,&tmaid->same);
 
 	/* ե */
-	if (ptw->fontname==NULL
-						|| (ptw->font=gdk_fontset_load(ptw->fontname))==NULL)
-		ptw->font=gdk_font_ref(system_font);
-	charset_size(ptw->font,&ptw->fontwidth,&ptw->fontheight,&ptw->fontascent);
+	if (tmaid->font_name==NULL
+					|| (tmaid->font=gdk_fontset_load(tmaid->font_name))==NULL)
+		tmaid->font=gdk_font_ref(system_font);
+	charset_size(tmaid->font,
+					&tmaid->font_width,&tmaid->font_height,&tmaid->font_ascent);
 
 	/* ɽꥢ */
-	ptw->drawing=gtk_drawing_area_new();
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"focus-in-event",
-								GTK_SIGNAL_FUNC(signal_focus_in),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"focus-out-event",
-								GTK_SIGNAL_FUNC(signal_focus_out),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"realize",
-								GTK_SIGNAL_FUNC(signal_realize),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"unrealize",
-								GTK_SIGNAL_FUNC(signal_unrealize),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"configure-event",
-								GTK_SIGNAL_FUNC(signal_config),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"expose-event",
-								GTK_SIGNAL_FUNC(signal_expose),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"button-press-event",
-								GTK_SIGNAL_FUNC(signal_button_press),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"motion-notify-event",
-								GTK_SIGNAL_FUNC(signal_motion_notify),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"button-release-event",
-								GTK_SIGNAL_FUNC(signal_button_release),ptw);
-	gtk_signal_connect_after(GTK_OBJECT(ptw->drawing),"key-press-event",
-								GTK_SIGNAL_FUNC(signal_key_press),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"destroy",
-								GTK_SIGNAL_FUNC(signal_destroy_draw),ptw);
-	gtk_widget_add_events(ptw->drawing,GDK_FOCUS_CHANGE | GDK_BUTTON_PRESS_MASK
-					| GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK
-														| GDK_BUTTON_RELEASE);
-	GTK_WIDGET_SET_FLAGS(ptw->drawing,GTK_CAN_FOCUS);
+	tmaid->drawing=gtk_drawing_area_new();
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"focus-in-event",
+								GTK_SIGNAL_FUNC(signal_focus_in),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"focus-out-event",
+								GTK_SIGNAL_FUNC(signal_focus_out),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"realize",
+								GTK_SIGNAL_FUNC(signal_realize),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"unrealize",
+								GTK_SIGNAL_FUNC(signal_unrealize),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"configure-event",
+								GTK_SIGNAL_FUNC(signal_config),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"expose-event",
+								GTK_SIGNAL_FUNC(signal_expose),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"button-press-event",
+								GTK_SIGNAL_FUNC(signal_button_press),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"motion-notify-event",
+								GTK_SIGNAL_FUNC(signal_motion_notify),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"button-release-event",
+								GTK_SIGNAL_FUNC(signal_button_release),tmaid);
+	gtk_signal_connect_after(GTK_OBJECT(tmaid->drawing),"key-press-event",
+								GTK_SIGNAL_FUNC(signal_key_press),tmaid);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"destroy",
+								GTK_SIGNAL_FUNC(signal_destroy_draw),tmaid);
+	gtk_widget_add_events(tmaid->drawing,
+			GDK_FOCUS_CHANGE | GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK
+						| GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_RELEASE);
+	GTK_WIDGET_SET_FLAGS(tmaid->drawing,GTK_CAN_FOCUS);
 	/* ץ饤ޥꥻ쥯 */
-	gtk_selection_add_targets(ptw->drawing,GDK_SELECTION_PRIMARY,targets,
+	gtk_selection_add_targets(tmaid->drawing,GDK_SELECTION_PRIMARY,targets,
 									sizeof(targets)/sizeof(GtkTargetEntry));
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"selection-get",
-													signal_selection_get,ptw);
+	gtk_signal_connect(GTK_OBJECT(tmaid->drawing),"selection-get",
+												signal_selection_get,tmaid);
 	/* С */
-	ptw->hscroll=gtk_hscrollbar_new(
+	tmaid->hscroll=gtk_hscrollbar_new(
 							GTK_ADJUSTMENT(gtk_adjustment_new(0,0,0,1,1,1)));
-	ptw->vscroll=gtk_vscrollbar_new(
+	tmaid->vscroll=gtk_vscrollbar_new(
 							GTK_ADJUSTMENT(gtk_adjustment_new(0,0,0,1,1,1)));
 	/* ơ֥ */
 	table=gtk_table_new(2,2,FALSE);
-	gtk_table_attach(GTK_TABLE(table),ptw->drawing,0,1,0,1,
+	gtk_table_attach(GTK_TABLE(table),tmaid->drawing,0,1,0,1,
 									GTK_EXPAND | GTK_SHRINK | GTK_FILL,
 									GTK_EXPAND | GTK_SHRINK | GTK_FILL,0,0);
-	gtk_table_attach(GTK_TABLE(table),ptw->hscroll,0,1,1,2,
+	gtk_table_attach(GTK_TABLE(table),tmaid->hscroll,0,1,1,2,
 							GTK_EXPAND | GTK_SHRINK | GTK_FILL,GTK_FILL,0,0);
-	gtk_table_attach(GTK_TABLE(table),ptw->vscroll,1,2,0,1,
+	gtk_table_attach(GTK_TABLE(table),tmaid->vscroll,1,2,0,1,
 							GTK_FILL,GTK_EXPAND | GTK_SHRINK | GTK_FILL,0,0);
-	gtk_object_set_user_data(GTK_OBJECT(table),ptw);
+	gtk_object_set_user_data(GTK_OBJECT(table),tmaid);
 	/* ˥塼 */
 	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
-	ptw->menu_item=gtk_menu_item_new_with_label(ptw->file);
-	gtk_signal_connect(GTK_OBJECT(ptw->menu_item),"activate",
+	tmaid->menu_item=gtk_menu_item_new_with_label(tmaid->file);
+	gtk_signal_connect(GTK_OBJECT(tmaid->menu_item),"activate",
 						GTK_SIGNAL_FUNC(signal_activate_menu_window),table);
-	gtk_menu_append(GTK_MENU(sub_menu),ptw->menu_item);
-	gtk_widget_show(ptw->menu_item);
+	gtk_menu_append(GTK_MENU(sub_menu),tmaid->menu_item);
+	gtk_widget_show(tmaid->menu_item);
 	/* ܥ */
 	button=gtk_button_new();
 	frame=gtk_frame_new(NULL);
@@ -408,24 +409,24 @@ TEXTWND *open_edit_file(gchar *file)
 	gtk_container_add(GTK_CONTAINER(button),frame);
 	gtk_signal_connect(GTK_OBJECT(button),"clicked",signal_clicked,table);
 	/* ٥ */
-	ptw->label=gtk_label_new(text);
+	tmaid->label=gtk_label_new(text);
 	g_free(text);
 	/* ɽ */
 	hbox=gtk_hbox_new(FALSE,4);
-	gtk_box_pack_start(GTK_BOX(hbox),ptw->label,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),tmaid->label,TRUE,TRUE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button,FALSE,FALSE,0);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook),table,hbox);
 	gtk_widget_show_all(hbox);
 	gtk_widget_show_all(table);
 	gtk_notebook_set_page(GTK_NOTEBOOK(notebook),
 						gtk_notebook_page_num(GTK_NOTEBOOK(notebook),table));
-	gtk_widget_grab_focus(ptw->drawing);
+	gtk_widget_grab_focus(tmaid->drawing);
 
 	/* ǤϤʤե뤬¸ߤˤ˲ä */
-	if (file!=NULL && history>0 && isfile(ptw->file))
-		set_history(ptw->file);
+	if (file!=NULL && history>0 && misc_isfile(tmaid->file))
+		file_set_history(tmaid->file);
 
-	return ptw;
+	return tmaid;
 }
 
 
@@ -435,22 +436,22 @@ TEXTWND *open_edit_file(gchar *file)
 *                                                                             *
 ******************************************************************************/
 /*	TXTե¸
-	file,ե̾
-	 ptw,TXTɥ
-	 RET,TRUE:ｪλ,FALSE:顼											*/
-gboolean save_text_file(gchar *file,TEXTWND *ptw)
+	 file,ե̾
+	tmaid,TXTɥ
+	  RET,TRUE:ｪλ,FALSE:顼										*/
+gboolean file_save_text(const gchar *file,TmaidWindow *tmaid)
 {
 	gboolean eof=FALSE;
 	FILE *fp;
-	LINEBUF *p;
+	LineBuffer *p;
 	GtkWidget *dialog;
 
-	p=ptw->start;
+	p=tmaid->start;
 	while (p->prev!=NULL)
 		p=p->prev;
 	/*  */
 	if ((fp=fopen(file,"wt"))==NULL) {
-		message_box("Text maid",_("Can not open file"),0,_("OK"),NULL);
+		misc_message_box("Text maid",_("Can not open file"),0,_("OK"),NULL);
 		return FALSE;
 	}
 	/* ܥå */
@@ -464,7 +465,7 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 		if (p->length>0 && fwrite(p->text,1,p->length,fp)!=p->length) {
 			gtk_grab_remove(dialog);
 			gtk_widget_destroy(dialog);
-			message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
+			misc_message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
 			fclose(fp);
 			return FALSE;
 		}
@@ -472,7 +473,8 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 			if (fputc('\n',fp)==EOF) {
 				gtk_grab_remove(dialog);
 				gtk_widget_destroy(dialog);
-				message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
+				misc_message_box("Text maid",_("Can not write"),0,
+																_("OK"),NULL);
 				fclose(fp);
 				return FALSE;
 			}
@@ -483,10 +485,10 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 		p=p->next;
 	}
 	/* Ǹ^Zդä */
-	if (userbreak && !eof && ptw->eof && fputc('\x1a',fp)==EOF) {
+	if (userbreak && !eof && tmaid->eof && fputc('\x1a',fp)==EOF) {
 		gtk_grab_remove(dialog);
 		gtk_widget_destroy(dialog);
-		message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
+		misc_message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
 		fclose(fp);
 		return FALSE;
 	}
@@ -494,7 +496,7 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 	gtk_grab_remove(dialog);
 	gtk_widget_destroy(dialog);
 	if (fclose(fp)!=0) {
-		message_box("Text maid","fclose",0,_("OK"),NULL);
+		misc_message_box("Text maid","fclose",0,_("OK"),NULL);
 		return FALSE;
 	}
 	return TRUE;
