@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@
 #include "edit.h"
 #include "find.h"
 #include "general.h"
-#include "other.h"
 #include "signal.h"
+#include "misc/misc.h"
 
 
 gboolean find_arrow=TRUE;					/*  */
@@ -41,8 +41,8 @@ gint find_num=0;							/* ϿƤ븡ʸ */
 /*	ʸμ
 	  type,ʸ°ǼХåե
 	  text,ʸ
-	length,ǡ													*/
-static void make_char_type(gint *type,gchar *text,gint length)
+	length,ǡ														*/
+static void make_char_type(gint *type,const gchar *text,const gint length)
 {
 	gint i=0,j;
 
@@ -58,45 +58,46 @@ static void make_char_type(gint *type,gchar *text,gint length)
 
 
 /*	
-	       ptw,TXTɥ
+	     tmaid,TXTɥ
 	     start,ϰ
 	       end,ϰ(x=-1ʤϰϤʤ)
 	      find,ʸ
 	     arrow,TRUE:,FALSE:
 	ignorecase,TRUE:ʸʸ̤,FALSE:ʸʸ̤ʤ	*/
-void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
-								gchar *find,gboolean arrow,gboolean ignorecase)
+void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
+			const gchar *find,const gboolean arrow,const gboolean ignorecase)
 {
 	gboolean result;			/* Ӥη,TRUE:Ʊ,FALSE:ۤʤ */
 	gchar *text;
 	gint i,max=0,sx,sy;
 	gint length0,length1=0;		/* ʸ(Хñ) */
 	gint *buf=NULL,*type=NULL;
-	LINEBUF *p,*q;
+	LineBuffer *p,*q;
 	GdkPoint cursor,select,top,st,ed,data;
 	GtkWidget *dialog;
 
 	st=*start;
 	ed=*end;
-	cursor=ptw->cursor;
-	ptw->cursor.x=get_align_pos(ptw,ptw->cursor.x,ptw->cursor.y,FALSE);
+	cursor=tmaid->cursor;
+	tmaid->cursor.x=edit_get_align_pos(tmaid,
+										tmaid->cursor.x,tmaid->cursor.y,FALSE);
 	length0=strlen(find);
 	for (i=0;i<256;i++)
 		if (charset->length[i]>max)
 			max=charset->length[i];
 	text=g_malloc((length0+max)*sizeof(gchar));
 	buf=g_malloc((length0+max)*sizeof(gint));
-	if (ptw->select.x>=0) {
+	if (tmaid->select.x>=0) {
 		/* ϰϤ */
-		select=ptw->select;
-		ptw->select.x=-1;
-		clear_sel(ptw,&select,&ptw->cursor);
+		select=tmaid->select;
+		tmaid->select.x=-1;
+		clear_sel(tmaid,&select,&tmaid->cursor);
 	}
 	if (ed.x>=0) {
 		/* ̤ˤΤȤˤ̵ */
-		i=get_sel_bytes(ptw,&st,&ed);
+		i=edit_get_sel_bytes(tmaid,&st,&ed);
 		if (i<=length0) {
-			cpy_sel_mem(ptw,&st,&ed,text);
+			edit_cpy_sel_mem(tmaid,&st,&ed,text);
 			text[i]='\0';
 			if (ignorecase)	/* ʸ/ʸ̤ */
 				result=strcmp(find,text)==0;
@@ -108,8 +109,8 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 	}
 	if (ed.x<0) {
 		if (arrow) {
-			ed.x=get_width(ptw,ptw->max-1);
-			ed.y=ptw->max-1;/*  */
+			ed.x=edit_get_width(tmaid,tmaid->max-1);
+			ed.y=tmaid->max-1;/*  */
 		} else {
 			ed.x=ed.y=0;/*  */
 		}
@@ -121,9 +122,9 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 	userbreak=TRUE;
 	dialog=abort_dialog(_("Finding"));
 	gtk_grab_add(dialog);
-	ed.x=get_data_pos(ptw,ed.x,ed.y,FALSE);
-	st.x=get_data_pos(ptw,st.x,st.y,FALSE);
-	p=get_line_buf(&ptw->start,&ptw->off,st.y);
+	ed.x=edit_get_data_pos(tmaid,ed.x,ed.y,FALSE);
+	st.x=edit_get_data_pos(tmaid,st.x,st.y,FALSE);
+	p=edit_get_line_buf(&tmaid->start,&tmaid->off,st.y);
 	/* ƱʸӤ뤿ʸ */
 	q=p;
 	data=st;
@@ -184,15 +185,15 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 					st.x=0;
 					st.y++;
 				}
-				ptw->select.x=get_screen_pos(ptw,st.x,st.y);
-				ptw->select.y=st.y;
+				tmaid->select.x=edit_get_screen_pos(tmaid,st.x,st.y);
+				tmaid->select.y=st.y;
 				if (q->margin && q->length<=data.x) {
 					/* ޡΤȤˤϼιԤƬ */
 					data.x=0;
 					data.y++;
 				}
-				ptw->cursor.x=get_screen_pos(ptw,data.x,data.y);
-				ptw->cursor.y=data.y;
+				tmaid->cursor.x=edit_get_screen_pos(tmaid,data.x,data.y);
+				tmaid->cursor.y=data.y;
 				break;
 			}
 			/* ХåեƬʸ˴ */
@@ -260,15 +261,15 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 					st.x=0;
 					st.y++;
 				}
-				ptw->select.x=get_screen_pos(ptw,st.x,st.y);
-				ptw->select.y=st.y;
+				tmaid->select.x=edit_get_screen_pos(tmaid,st.x,st.y);
+				tmaid->select.y=st.y;
 				if (q->margin && q->length<=data.x) {
 					/* ޡΤȤˤϼιԤƬ */
 					data.x=0;
 					data.y++;
 				}
-				ptw->cursor.x=get_screen_pos(ptw,data.x,data.y);
-				ptw->cursor.y=data.y;
+				tmaid->cursor.x=edit_get_screen_pos(tmaid,data.x,data.y);
+				tmaid->cursor.y=data.y;
 				break;
 			}
 			/* ХåեκǸʸ˴ */
@@ -287,26 +288,26 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 	/* λ */
 	gtk_grab_remove(dialog);
     gtk_widget_destroy(dialog);
-	if (ptw->select.x>=0) {
-		top=ptw->top;
-		sx=MAX(ptw->drawing->allocation.width/ptw->fontwidth,1);
-		sy=MAX(ptw->drawing->allocation.height/ptw->fontheight,1);
-		if (ptw->cursor.x<ptw->top.x)
-			ptw->top.x=ptw->cursor.x;
-		else if (ptw->cursor.x-sx+1>ptw->top.x)
-			ptw->top.x=ptw->cursor.x-sx+1;
-		if (ptw->cursor.y<ptw->top.y)
-			ptw->top.y=ptw->cursor.y;
-		else if (ptw->cursor.y-sy+1>ptw->top.y)
-			ptw->top.y=ptw->cursor.y-sy+1;
-		move_edit_window(ptw,&top);
-		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw)+1,sx,ptw->top.x);
-		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max,sy,ptw->top.y);
-		clear_sel(ptw,&ptw->select,&ptw->cursor);
-		draw_caret(ptw,&cursor);
-		gtk_selection_owner_set(ptw->drawing,GDK_SELECTION_PRIMARY,
+	if (tmaid->select.x>=0) {
+		top=tmaid->top;
+		sx=MAX(tmaid->drawing->allocation.width/tmaid->font_width,1);
+		sy=MAX(tmaid->drawing->allocation.height/tmaid->font_height,1);
+		if (tmaid->cursor.x<tmaid->top.x)
+			tmaid->top.x=tmaid->cursor.x;
+		else if (tmaid->cursor.x-sx+1>tmaid->top.x)
+			tmaid->top.x=tmaid->cursor.x-sx+1;
+		if (tmaid->cursor.y<tmaid->top.y)
+			tmaid->top.y=tmaid->cursor.y;
+		else if (tmaid->cursor.y-sy+1>tmaid->top.y)
+			tmaid->top.y=tmaid->cursor.y-sy+1;
+		move_edit_window(tmaid,&top);
+		misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
+								0,edit_get_width_max(tmaid)+1,sx,tmaid->top.x);
+		misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
+								0,tmaid->max,sy,tmaid->top.y);
+		clear_sel(tmaid,&tmaid->select,&tmaid->cursor);
+		draw_caret(tmaid,&cursor);
+		gtk_selection_owner_set(tmaid->drawing,GDK_SELECTION_PRIMARY,
 															GDK_CURRENT_TIME);
 	}
 }
@@ -322,7 +323,7 @@ static GtkWidget *dialog,*check,*combo,*radio1;
 
 
 /* OKܥ󤬲줿 */
-static void find_dialog_clicked(GtkWidget *widget,FIND *fd)
+static void find_dialog_clicked(GtkWidget *widget,FindString *fd)
 {
 	fd->text=g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry)));
 	fd->ignorecase=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
@@ -333,7 +334,7 @@ static void find_dialog_clicked(GtkWidget *widget,FIND *fd)
 
 
 /* ȥ꡼ǥ꥿󤬲줿 */
-static void find_dialog_activate(GtkWidget *widget,FIND *fd)
+static void find_dialog_activate(GtkWidget *widget,FindString *fd)
 {
 	if (strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0)
 		find_dialog_clicked(widget,fd);
@@ -358,7 +359,7 @@ static gboolean find_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 }
 
 
-gboolean find_dialog(FIND *fd)
+gboolean find_dialog(FindString *fd)
 {
 	gint i;
 	guint key;
