@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -61,13 +61,13 @@ static void format_dialog_unselect_row(GtkWidget *widget,
 /*  */
 static void format_dialog_clicked_new(GtkWidget *widget,GtkWidget *clist)
 {
-	ftype=g_realloc(ftype,++ftnum*sizeof(FTYPE));
-	memmove(ftype+ftpos+2,ftype+ftpos+1,(ftnum-ftpos-2)*sizeof(FTYPE));
+	ftype=g_realloc(ftype,++ftnum*sizeof(FileType));
+	memmove(ftype+ftpos+2,ftype+ftpos+1,(ftnum-ftpos-2)*sizeof(FileType));
 	ftype[ftpos+1]=ftype[ftpos];
 	ftype[ftpos+1].ft_id=tcount++;
 	ftype[ftpos+1].text=g_strdup(ftype[ftpos].text);
 	ftype[ftpos+1].ext=g_strdup(ftype[ftpos].ext);
-	ftype[ftpos+1].fontname=g_strdup(ftype[ftpos].fontname);
+	ftype[ftpos+1].font_name=g_strdup(ftype[ftpos].font_name);
 	gtk_clist_insert(GTK_CLIST(clist),ftpos+1,&ftype[ftpos+1].text);
 }
 
@@ -77,10 +77,10 @@ static void format_dialog_clicked_remove(GtkWidget *widget,GtkWidget *clist)
 {
 	g_free(ftype[ftpos].text);
 	g_free(ftype[ftpos].ext);
-	g_free(ftype[ftpos].fontname);
+	g_free(ftype[ftpos].font_name);
 	ftnum--;
-	memmove(ftype+ftpos,ftype+ftpos+1,(ftnum-ftpos)*sizeof(FTYPE));
-	ftype=g_realloc(ftype,ftnum*sizeof(FTYPE));
+	memmove(ftype+ftpos,ftype+ftpos+1,(ftnum-ftpos)*sizeof(FileType));
+	ftype=g_realloc(ftype,ftnum*sizeof(FileType));
 	gtk_clist_remove(GTK_CLIST(clist),ftpos);
 }
 
@@ -88,7 +88,7 @@ static void format_dialog_clicked_remove(GtkWidget *widget,GtkWidget *clist)
 /*  */
 static void format_dialog_clicked_up(GtkWidget *widget,GtkWidget *clist)
 {
-	FTYPE ft;
+	FileType ft;
 
 	ft=ftype[ftpos];
 	ftype[ftpos]=ftype[ftpos-1];
@@ -102,7 +102,7 @@ static void format_dialog_clicked_up(GtkWidget *widget,GtkWidget *clist)
 /*  */
 static void format_dialog_clicked_down(GtkWidget *widget,GtkWidget *clist)
 {
-	FTYPE ft;
+	FileType ft;
 
 	ft=ftype[ftpos];
 	ftype[ftpos]=ftype[ftpos+1];
@@ -118,15 +118,15 @@ static void format_dialog_clicked_edit(GtkWidget *widget,GtkWidget *clist)
 {
 	gint i;
 	GList *glist;
-	TEXTWND *ptw;
+	TmaidWindow *tmaid;
 
 	property_dialog(ftype+ftpos);
 	gtk_clist_set_text(GTK_CLIST(clist),ftpos,0,ftype[ftpos].text);
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
 	for (i=g_list_length(glist)-1;i>=0;i--) {
-		ptw=gtk_object_get_user_data(GTK_OBJECT(g_list_nth_data(glist,i)));
-		if (ptw->ft_id==ftype[ftpos].ft_id)
-			change_property(ptw,&ftype[ftpos]);
+		tmaid=gtk_object_get_user_data(GTK_OBJECT(g_list_nth_data(glist,i)));
+		if (tmaid->ft_id==ftype[ftpos].ft_id)
+			property_change(tmaid,&ftype[ftpos]);
 	}
 	g_list_free(glist);
 }
