@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,18 +23,18 @@
 #include "tmaid.h"
 
 
-typedef struct jmpdlg {
+typedef struct JumpDialog_Tag {
 	gint cursor,max;
-} JMPDLG;
+} JumpDialog;
 
 
 /*	Ԥذư
-	 ptw,TXTɥ
-	line,(1...)														*/
-void jump_operation(TEXTWND *ptw,gint line);
+	tmaid,TXTɥ
+	 line,(1...)													*/
+void jump_operation(TmaidWindow *tmaid,const gint line);
 
 
-gboolean jump_dialog(JMPDLG *jmp);
+gboolean jump_dialog(JumpDialog *jmp);
 
 
 #endif
