@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,10 +25,10 @@
 #include "abort.h"
 #include "charset.h"
 #include "edit.h"
-#include "other.h"
+#include "misc/misc.h"
 
 
-PRNCFG printer;						/*  */
+PrintConfig printer;						/*  */
 
 
 /******************************************************************************
@@ -36,44 +36,47 @@ PRNCFG printer;						/*  */
 * ؿ                                                                  *
 *                                                                             *
 ******************************************************************************/
-gboolean print_out(TEXTWND *ptw,PRNCFG *prncfg)
+gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 {
 	guchar *c;
-	gint i,x,y,sx,sy,datapos,endpos,line,width,channels,rowstride;
+	gint i,x,y,sx,sy,data_pos,end_pos,line,width,channels,rowstride;
 	FILE *fp;
-	LINEBUF *p;
+	LineBuffer *p;
 	GdkGC *gc;
 	GdkPixmap *pixmap;
 	GdkPixbuf *pixbuf;
 	GdkPoint start,end;
 	GtkWidget *dialog;
 
-	sx=prncfg->column*prncfg->fontwidth;
+	sx=prncfg->column*prncfg->font_width;
 	sy=sx*(prncfg->height-prncfg->left-prncfg->right)
 								/(prncfg->width-prncfg->top-prncfg->bottom);
-	if (ptw->select.x<0 || !prncfg->select) {
+	if (tmaid->select.x<0 || !prncfg->select) {
 		/* ϰϤʤ٤ư */
 		start.x=start.y=0;
-		end.x=get_width(ptw,ptw->max-1);
-		end.y=ptw->max-1;
-	} else if (ptw->select.y<ptw->cursor.y
-			|| (ptw->select.y==ptw->cursor.y && ptw->select.x<ptw->cursor.x)) {
-		start=ptw->select;
-		end=ptw->cursor;
+		end.x=edit_get_width(tmaid,tmaid->max-1);
+		end.y=tmaid->max-1;
+	} else if (tmaid->select.y<tmaid->cursor.y
+										|| (tmaid->select.y==tmaid->cursor.y
+										&& tmaid->select.x<tmaid->cursor.x)) {
+		start=tmaid->select;
+		end=tmaid->cursor;
 	} else {
-		start=ptw->cursor;
-		end=ptw->select;
+		start=tmaid->cursor;
+		end=tmaid->select;
 	}
 	if (prncfg->mode) {
 		/* ץ */
 		if ((fp=popen(prncfg->printer,"w"))==NULL) {
-			message_box("Text maid",_("Can not open printer"),0,_("OK"),NULL);
+			misc_message_box("Text maid",_("Can not open printer"),0,
+																_("OK"),NULL);
 			return FALSE;
 		}
 	} else {
 		/* ե */
 		if ((fp=fopen(prncfg->file,"wt"))==NULL) {
-			message_box("Text maid",_("Can not open file"),0,_("OK"),NULL);
+			misc_message_box("Text maid",_("Can not open file"),0,
+																_("OK"),NULL);
 			return FALSE;
 		}
 	}
@@ -85,11 +88,11 @@ gboolean print_out(TEXTWND *ptw,PRNCFG *prncfg)
 								GDK_LINE_SOLID,GDK_CAP_BUTT,GDK_JOIN_MITER);
 	for (i=10;i<12;i++)
 		gdk_color_alloc(gdk_colormap_get_system(),
-									(ptw->syscol?system_color:ptw->color)+i);
-	p=get_line_buf(&ptw->start,&ptw->off,start.y);
-	endpos=get_data_pos(ptw,end.x,end.y,FALSE);
+								(tmaid->syscol?system_color:tmaid->color)+i);
+	p=edit_get_line_buf(&tmaid->start,&tmaid->off,start.y);
+	end_pos=edit_get_data_pos(tmaid,end.x,end.y,FALSE);
 	line=start.y;
-	datapos=get_data_pos(ptw,start.x,start.y,FALSE);
+	data_pos=edit_get_data_pos(tmaid,start.x,start.y,FALSE);
 	/* ܥå */
 	userbreak=TRUE;
 	dialog=abort_dialog(_("Printing"));
@@ -97,52 +100,52 @@ gboolean print_out(TEXTWND *ptw,PRNCFG *prncfg)
 	while (line<=end.y) {
 		/* ڡ */
 		/* ط */
-		gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)+11);
+		gdk_gc_set_foreground(gc,(tmaid->syscol?system_color:tmaid->color)+11);
 		gdk_draw_rectangle(pixmap,gc,TRUE,0,0,sx,sy);
-		gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)+10);
+		gdk_gc_set_foreground(gc,(tmaid->syscol?system_color:tmaid->color)+10);
 		x=y=0;
-		while (y<=sy-ptw->fontheight && line<=end.y) {
+		while (y<=sy-tmaid->font_height && line<=end.y) {
 			while (gtk_events_pending())
 				gtk_main_iteration();
 			while (x<sx) {
-				if (datapos>=(line==end.y?endpos:p->length)) {
+				if (data_pos>=(line==end.y?end_pos:p->length)) {
 					/* Ԥν */
-					datapos=0;
+					data_pos=0;
 					line++;
 					p=p->next;
 					if (p==NULL || !p->margin)
 						break;
 				}
-				if (p->text[datapos]=='\t')
-					width=(x/ptw->fontwidth/ptw->tab+1)*ptw->tab
-															*ptw->fontwidth-x;
-				else if (datapos+charset_length(p->text[datapos])<=p->length)
-					width=ptw->fontwidth*charset_width(ptw->font,
-											p->text+datapos,ptw->fontwidth);
+				if (p->text[data_pos]=='\t')
+					width=(x/tmaid->font_width/tmaid->tab+1)*tmaid->tab
+														*tmaid->font_width-x;
+				else if (data_pos+charset_length(p->text[data_pos])<=p->length)
+					width=tmaid->font_width*charset_width(tmaid->font,
+										p->text+data_pos,tmaid->font_width);
 				else
-					width=ptw->fontwidth;
+					width=tmaid->font_width;
 				if (x>0 && sx<x+width)
 					break;
-				if (p->text[datapos]=='\t') {
+				if (p->text[data_pos]=='\t') {
 					/*  */
-					datapos++;
-				} else if (datapos+charset_length(p->text[datapos])
+					data_pos++;
+				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
 					/* Ⱦ/ */
-					gdk_draw_text(pixmap,ptw->font,gc,
-										x,y+ptw->fontascent,p->text+datapos,
-											charset_length(p->text[datapos]));
-					datapos+=charset_length(p->text[datapos]);
+					gdk_draw_text(pixmap,tmaid->font,gc,
+									x,y+tmaid->font_ascent,p->text+data_pos,
+											charset_length(p->text[data_pos]));
+					data_pos+=charset_length(p->text[data_pos]);
 				} else {
 					/* Ⱦ */
-					gdk_draw_text(pixmap,ptw->font,gc,
-										x,y+ptw->fontascent,p->text+datapos,1);
-					datapos++;
+					gdk_draw_text(pixmap,tmaid->font,gc,
+									x,y+tmaid->font_ascent,p->text+data_pos,1);
+					data_pos++;
 				}
 				x+=width;
 			}
 			x=0;
-			y+=ptw->fontheight;
+			y+=tmaid->font_height;
 		}
 		fprintf(fp,
 			"%d %d translate\n"
@@ -218,13 +221,13 @@ static GtkWidget *label1,*label2,*label3;
 static GtkWidget *spin0,*spin1,*spin2,*spin3,*spin4,*spin5,*spin6;
 static struct {
 	gchar *name;
-	gint width,height;
+	const gint width,height;
 } paper[]={	{"A3",840,1188},{"A4",594,840},{"A5",420,594},
 			{"B4",730,1030},{"B5",515,730},{NULL,0,0}};
 
 
 /* OKܥɽ/ɽȽ */
-static void print_dialog_ok_sensitive(GtkWidget *widget,PRNCFG *prncfg)
+static void print_dialog_ok_sensitive(GtkWidget *widget,PrintConfig *prncfg)
 {
 	gint column,row,width,height,left,top,right,bottom;
 
@@ -238,7 +241,7 @@ static void print_dialog_ok_sensitive(GtkWidget *widget,PRNCFG *prncfg)
 	width-=left+right;
 	height-=top+bottom;
 	row=left>=0 && top>=0 && right>=0 && bottom>=0 && width>0 && height>0
-				?column*prncfg->fontwidth*height/(width*prncfg->fontheight):0;
+			?column*prncfg->font_width*height/(width*prncfg->font_height):0;
 	gtk_widget_set_sensitive(button1,column>=1 && row>=1
 		&& strlen(gtk_entry_get_text(GTK_ENTRY(gtk_toggle_button_get_active(
 								GTK_TOGGLE_BUTTON(radio0))?entry0:entry1)))>0);
@@ -246,7 +249,7 @@ static void print_dialog_ok_sensitive(GtkWidget *widget,PRNCFG *prncfg)
 
 
 /* ԥܥѲ */
-static void print_dialog_changed_spin(GtkWidget *widget,PRNCFG *prncfg)
+static void print_dialog_changed_spin(GtkWidget *widget,PrintConfig *prncfg)
 {
 	gchar *text;
 	gint column,row,width,height,left,top,right,bottom;
@@ -261,7 +264,7 @@ static void print_dialog_changed_spin(GtkWidget *widget,PRNCFG *prncfg)
 	width-=left+right;
 	height-=top+bottom;
 	row=left>=0 && top>=0 && right>=0 && bottom>=0 && width>0 && height>0
-				?column*prncfg->fontwidth*height/(width*prncfg->fontheight):0;
+			?column*prncfg->font_width*height/(width*prncfg->font_height):0;
 	text=g_strdup_printf(_("%d Lines"),MAX(row,0));
 	gtk_label_set_text(GTK_LABEL(label1),text);
 	g_free(text);
@@ -297,7 +300,7 @@ static void print_dialog_changed_combo(GtkWidget *widget,gpointer user_data)
 
 
 /* åܥ/饸ܥ */
-static void print_dialog_toggled(GtkWidget *widget,PRNCFG *prncfg)
+static void print_dialog_toggled(GtkWidget *widget,PrintConfig *prncfg)
 {
 	gboolean result;
 
@@ -310,7 +313,7 @@ static void print_dialog_toggled(GtkWidget *widget,PRNCFG *prncfg)
 
 
 /* OKܥ󤬲줿 */
-static void print_dialog_clicked_ok(GtkWidget *widget,PRNCFG *prncfg)
+static void print_dialog_clicked_ok(GtkWidget *widget,PrintConfig *prncfg)
 {
 	prncfg->mode=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio0));
 	if (prncfg->mode) {
@@ -333,24 +336,24 @@ static void print_dialog_clicked_ok(GtkWidget *widget,PRNCFG *prncfg)
 }
 
 
-static gchar *print_open_file;
-
-
 /* եλȤOKܥ󤬲줿 */
 static void print_open_ok(GtkWidget *widget,GtkWidget *dialog_open)
 {
-	print_open_file=g_strdup(gtk_file_selection_get_filename(
+	gchar **file;
+
+	file=gtk_object_get_user_data(GTK_OBJECT(dialog_open));
+	*file=g_strdup(gtk_file_selection_get_filename(
 											GTK_FILE_SELECTION(dialog_open)));
     gtk_widget_destroy(dialog_open);
 }
 
 
 /* ȥܥ󤬲줿 */
-static void print_dialog_clicked_file(GtkWidget *widget,PRNCFG *prncfg)
+static void print_dialog_clicked_file(GtkWidget *widget,PrintConfig *prncfg)
 {
+	gchar *file=NULL;
 	GtkWidget *dialog_open;
 
-	print_open_file=NULL;
 	dialog_open=gtk_file_selection_new(_("Save As"));
 	gtk_signal_connect(GTK_OBJECT(dialog_open),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog_open)->ok_button),
@@ -360,18 +363,19 @@ static void print_dialog_clicked_file(GtkWidget *widget,PRNCFG *prncfg)
 						"clicked",gtk_widget_destroy,GTK_OBJECT(dialog_open));
 	gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog_open),
 										gtk_entry_get_text(GTK_ENTRY(entry1)));
+	gtk_object_set_user_data(GTK_OBJECT(dialog_open),&file);
 	gtk_widget_show(dialog_open);
 	gtk_grab_add(dialog_open);
 	gtk_main();
-	if (print_open_file!=NULL) {
-		gtk_entry_set_text(GTK_ENTRY(entry1),print_open_file);
-		g_free(print_open_file);
+	if (file!=NULL) {
+		gtk_entry_set_text(GTK_ENTRY(entry1),file);
+		g_free(file);
 	}
 }
 
 
 /* ȥ꡼/ԥܥǥ꥿󤬲줿 */
-static void print_dialog_activate(GtkWidget *widget,PRNCFG *prncfg)
+static void print_dialog_activate(GtkWidget *widget,PrintConfig *prncfg)
 {
 	gint left,top,right,bottom;
 
@@ -399,7 +403,7 @@ static gboolean print_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 }
 
 
-gboolean print_dialog(PRNCFG *prncfg)
+gboolean print_dialog(PrintConfig *prncfg)
 {
 	gint i;
 	guint key;
@@ -562,8 +566,7 @@ gboolean print_dialog(PRNCFG *prncfg)
 	for (i=0;paper[i].name!=NULL;i++)
 		if (paper[i].width==prncfg->width && paper[i].height==prncfg->height)
 			break;
-	if (paper[i].name==NULL) {
-	} else {
+	if (paper[i].name!=NULL) {
 		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry),paper[i].name);
 	}
 
