@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,8 +18,13 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
+#include "charset.h"
+#include "edit.h"
 #include "ftype.h"
+#include "general.h"
 #include "prop.h"
+#include "signal.h"
+#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -27,8 +32,95 @@
 * ץѥƥؿ                                                            *
 *                                                                             *
 ******************************************************************************/
+/*	ץѥƥѹ
+	tmaid,TXTɥ
+	   ft,ե륿													*/
+void property_change(TmaidWindow *tmaid,FileType *ft)
+{
+	gboolean modify;
+	gint max,sx,sy;
+
+	if (tmaid->limit!=ft->limit || tmaid->tab!=ft->tab
+							|| (tmaid->code && tmaid->margin!=ft->margin)) {
+		/* ޤ֤ѹֿѹ */
+		delete_list(&tmaid->undo);
+		delete_list(&tmaid->redo);
+	}
+	modify=tmaid->limit!=ft->limit || (tmaid->limit
+						&& (tmaid->tab!=ft->tab || tmaid->margin!=ft->margin
+								|| strcmp(tmaid->font_name,ft->font_name)!=0));
+	tmaid->ft_id=ft->ft_id;
+	tmaid->margin=ft->margin;
+	tmaid->tab=ft->tab;
+	tmaid->autoindent=ft->autoindent;
+	tmaid->code=ft->code;
+	tmaid->crlf=ft->crlf;
+	tmaid->eof=ft->eof;
+	tmaid->limit=ft->limit;
+	tmaid->overwrite=ft->overwrite;
+	tmaid->space=ft->space;
+	tmaid->syscol=ft->syscol;
+	tmaid->gline=ft->gline;
+	tmaid->mline=ft->mline;
+	tmaid->uline=ft->uline;
+	tmaid->vline=ft->vline;
+	g_free(tmaid->font_name);
+	tmaid->font_name=g_strdup(ft->font_name);
+	memcpy(tmaid->color,ft->color,sizeof(GdkColor)*12);
+	tmaid->select.x=-1;
+	/* ե */
+	if (tmaid->font_name!=NULL) {
+		gdk_font_unref(tmaid->font);
+		if ((tmaid->font=gdk_fontset_load(tmaid->font_name))==NULL)
+			tmaid->font=gdk_font_ref(system_font);
+		charset_size(tmaid->font,
+				&tmaid->font_width,&tmaid->font_height,&tmaid->font_ascent);
+	}
+	if (modify) {
+		/* ޤ֤ѹ
+							ޤ֤ͭǥֿ䱦ޡեѹ */
+		tmaid->cursor.x=tmaid->cursor.y=tmaid->top.x=tmaid->top.y=0;
+		modify_margin(tmaid);
+	}
+	/* С */
+	sx=MAX(tmaid->drawing->allocation.width/tmaid->font_width,1);
+	sy=MAX(tmaid->drawing->allocation.height/tmaid->font_height,1);
+	if (tmaid->top.y>tmaid->max-sy)
+		tmaid->top.y=MAX(tmaid->max-sy,0);
+	max=edit_get_width_max(tmaid);
+	if (tmaid->top.x>max-sx+1)
+		tmaid->top.x=MAX(max-sx+1,0);
+	misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
+												0,max+1,sx,tmaid->top.x);
+	misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
+												0,tmaid->max,sy,tmaid->top.y);
+	/*  */
+	gtk_widget_draw(tmaid->drawing,NULL);
+	draw_caret(tmaid,NULL);
+#ifdef USE_XIM
+	if (gdk_im_ready() && tmaid->ic!=NULL
+				&& (gdk_ic_get_style(tmaid->ic)&GDK_IM_PREEDIT_POSITION)!=0) {
+		gdk_ic_get_attr(tmaid->ic,tmaid->ic_attr,GDK_IC_PREEDIT_FONTSET
+					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
+		tmaid->ic_attr->preedit_foreground=tmaid->syscol
+											?system_color[0]:tmaid->color[0];
+		tmaid->ic_attr->preedit_background=tmaid->syscol
+											?system_color[1]:tmaid->color[1];
+		tmaid->ic_attr->preedit_fontset=tmaid->font;
+		gdk_ic_set_attr(tmaid->ic,tmaid->ic_attr,GDK_IC_PREEDIT_FONTSET
+					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
+	}
+#endif
+}
+
+
+/******************************************************************************
+*                                                                             *
+* ץѥƥؿ                                                  *
+*                                                                             *
+******************************************************************************/
 static gboolean property_clicked_ok,color_list[12];
-static gchar *fontname;
+static gchar *font_name;
 static gint ft_id;
 static GdkColor gdk_color[12];
 static GtkWidget *dialog;
@@ -160,8 +252,8 @@ static void property_dialog_clicked_font_ok(GtkWidget *widget,
 	name=gtk_font_selection_dialog_get_font_name(
 									GTK_FONT_SELECTION_DIALOG(dialog_font));
 	if (name!=NULL && name[0]!='\0') {
-		g_free(fontname);
-		fontname=name;
+		g_free(font_name);
+		font_name=name;
 		property_dialog_ok_sensitive(NULL,NULL);
 	}
     gtk_widget_destroy(dialog_font);
@@ -181,9 +273,9 @@ static void property_dialog_clicked_font(GtkWidget *widget,gpointer user_data)
 	gtk_signal_connect_object(
 			GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(dialog_font)->cancel_button),
 						"clicked",gtk_widget_destroy,GTK_OBJECT(dialog_font));
-	if (fontname!=NULL)
+	if (font_name!=NULL)
 		gtk_font_selection_dialog_set_font_name(
-							GTK_FONT_SELECTION_DIALOG(dialog_font),fontname);
+							GTK_FONT_SELECTION_DIALOG(dialog_font),font_name);
 	gtk_widget_show(dialog_font);
 	gtk_grab_add(dialog_font);
 	gtk_main();
@@ -227,8 +319,8 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 														ftype[pos].margin);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),ftype[pos].tab);
 			memcpy(gdk_color,ftype[pos].color,sizeof(GdkColor)*12);
-			g_free(fontname);
-			fontname=g_strdup(ftype[pos].fontname);
+			g_free(font_name);
+			font_name=g_strdup(ftype[pos].font_name);
 			gtk_widget_set_sensitive(button3,TRUE);
 		} else {
 			ft_id=-1;
@@ -240,7 +332,7 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 
 
 /* OKܥ󤬲줿 */
-static void property_dialog_clicked_ok(GtkWidget *widget,FTYPE *ft)
+static void property_dialog_clicked_ok(GtkWidget *widget,FileType *ft)
 {
 	ft->ft_id=ft_id;
 	if (entry0!=NULL) {
@@ -268,16 +360,16 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FTYPE *ft)
 	if (check12!=NULL)
 		ft->associate=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check12));
 	memcpy(ft->color,gdk_color,sizeof(GdkColor)*12);
-	g_free(ft->fontname);
-	ft->fontname=fontname;
-	fontname=NULL;
+	g_free(ft->font_name);
+	ft->font_name=font_name;
+	font_name=NULL;
     gtk_widget_destroy(dialog);
 	property_clicked_ok=TRUE;
 }
 
 
 /* ԥܥǥ꥿󤬲줿 */
-static void property_dialog_activate(GtkWidget *widget,FTYPE *ft)
+static void property_dialog_activate(GtkWidget *widget,FileType *ft)
 {
 	if ((entry0==NULL || strlen(gtk_entry_get_text(GTK_ENTRY(entry0)))>0)
 		&& (entry1==NULL || strlen(gtk_entry_get_text(GTK_ENTRY(entry1)))>0))
@@ -295,7 +387,7 @@ static gboolean property_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 }
 
 
-gboolean property_dialog(FTYPE *ft)
+gboolean property_dialog(FileType *ft)
 {
 	gchar *text,*xpm[18];
 	gint i;
@@ -619,7 +711,7 @@ gboolean property_dialog(FTYPE *ft)
 
 	ft_id=ft->ft_id;
 	memcpy(gdk_color,ft->color,sizeof(GdkColor)*12);
-	fontname=g_strdup(ft->fontname);
+	font_name=g_strdup(ft->font_name);
 	property_clicked_ok=FALSE;
 
 	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
@@ -627,7 +719,7 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_widget_show_all(dialog);
 	gtk_main();
 
-	g_free(fontname);
+	g_free(font_name);
 
 	return property_clicked_ok;
 }
