@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,31 +38,31 @@ static GtkWidget *dialog,*check,*combo0,*combo1,*radio1,*button0,*button1;
 
 
 /* ִܥ󤬲줿 */
-static void replace_dialog_clicked_ok(GtkWidget *widget,REPLACE *rp)
+static void replace_dialog_clicked_ok(GtkWidget *widget,ReplaceString *rp)
 {
 	rp->src=g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)));
 	rp->dst=g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo1)->entry)));
 	rp->ignorecase=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
 	rp->arrow=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio1));
 	gtk_widget_destroy(dialog);
-	replace_clicked_button=1;
+	replace_clicked_button=REPLACE_OK;
 }
 
 
 /* ٤ִܥ󤬲줿 */
-static void replace_dialog_clicked_all(GtkWidget *widget,REPLACE *rp)
+static void replace_dialog_clicked_all(GtkWidget *widget,ReplaceString *rp)
 {
 	rp->src=g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)));
 	rp->dst=g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo1)->entry)));
 	rp->ignorecase=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
 	rp->arrow=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio1));
 	gtk_widget_destroy(dialog);
-	replace_clicked_button=2;
+	replace_clicked_button=REPLACE_ALL;
 }
 
 
 /* ȥ꡼ǥ꥿󤬲줿 */
-static void replace_dialog_activate(GtkWidget *widget,REPLACE *rp)
+static void replace_dialog_activate(GtkWidget *widget,ReplaceString *rp)
 {
 	if (strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)))>0)
 		replace_dialog_clicked_ok(widget,rp);
@@ -89,7 +89,7 @@ static gboolean replace_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 }
 
 
-gint replace_dialog(REPLACE *rp)
+gint replace_dialog(ReplaceString *rp)
 {
 	gint i;
 	guint key;
@@ -210,7 +210,7 @@ gint replace_dialog(REPLACE *rp)
 	gtk_widget_set_sensitive(button1,
 			strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo0)->entry)))>0);
 	gtk_widget_grab_focus(GTK_COMBO(combo0)->entry);
-	replace_clicked_button=-1;
+	replace_clicked_button=REPLACE_CANCEL;
 
 	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
 	gtk_grab_add(dialog);
