@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,24 +29,24 @@
 #include "format.h"
 #include "general.h"
 #include "jump.h"
-#include "other.h"
 #ifdef USE_GDKPIXBUF
 #include "print.h"
 #endif
-#include "profile.h"
 #include "replace.h"
 #include "signal.h"
 #include "toolbar.h"
 #include "version.h"
+#include "misc/misc.h"
+#include "misc/profile.h"
 
 
 gboolean caret=FALSE;				/* åȤη */
 gboolean ins=TRUE;					/* TRUE:,FALSE: */
 gboolean newfile=FALSE;				/* TRUE:ե,FALSE:ʤ */
 gboolean second=FALSE;				/* TRUE:,FALSE:¸ */
-gchar *hisfile[10];					/* ե */
-gchar *openpath=NULL;				/* Υѥ */
-gchar *savepath=NULL;				/* ̾դ¸Υѥ */
+gchar *history_files[10];					/* ե */
+gchar *open_path=NULL;				/* Υѥ */
+gchar *save_path=NULL;				/* ̾դ¸Υѥ */
 gchar *clipboard_text=NULL;			/* åץܡɤΥƥ */
 gchar *arg_text=NULL;				/* ץ̿ѿ */
 gint def_width,def_height;			/* ǥեȤΥɥΥ */
@@ -56,7 +56,7 @@ gint init_line=0;					/* ΥåȰ */
 gint instance=-1;					/* ץ̿ѿ */
 gint tcount=0;						/* ե륿פΥ */
 guint timer_id=0;					/* ID */
-FTYPE *ftype=NULL;					/* ե륿 */
+FileType *ftype=NULL;				/* ե륿 */
 GdkAtom atom_clipboard;				/* åץܡ */
 GdkAtom atom_targets;				/* å */
 GdkAtom atom_compound;				/* ѥ */
@@ -98,8 +98,8 @@ int main(int argc,char *argv[])
 	gboolean *arg_files;
 	gchar *arg,*section,*key;
 	gint i,count=0,leng,length=0;
-	PROFILE *profile;
-	TEXTWND *ptw;
+	Profile *profile;
+	TmaidWindow *tmaid;
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
@@ -170,7 +170,7 @@ int main(int argc,char *argv[])
 
 	def_width=gdk_screen_width()*2/3;
 	def_height=gdk_screen_height()*2/3;
-	memset(hisfile,0,sizeof(gchar *)*10);
+	memset(history_files,0,sizeof(gchar *)*10);
 	/* 쥸ȥ꤫ɤ߽Ф */
 	if ((profile=profile_open(".tmaid"))!=NULL) {
 		if (!profile_get_value(profile,"tmaid","ftnum",
@@ -194,18 +194,18 @@ int main(int argc,char *argv[])
 		if (!profile_get_value(profile,"tmaid","n_pos",
 						(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			n_pos=GTK_POS_TOP;
-		openpath=profile_get_string(profile,"tmaid","openpath");
-		savepath=profile_get_string(profile,"tmaid","savepath");
+		open_path=profile_get_string(profile,"tmaid","openpath");
+		save_path=profile_get_string(profile,"tmaid","savepath");
 		/* ե */
 		for (i=0;i<history;i++) {
 			key=g_strdup_printf("history%d",i);
-			hisfile[i]=profile_get_string(profile,"tmaid",key);
+			history_files[i]=profile_get_string(profile,"tmaid",key);
 			g_free(key);
-			if (hisfile[i]==NULL)
+			if (history_files[i]==NULL)
 				break;
-			if (*hisfile[i]=='\0') {
-				g_free(hisfile[i]);
-				hisfile[i]=NULL;
+			if (*history_files[i]=='\0') {
+				g_free(history_files[i]);
+				history_files[i]=NULL;
 				break;
 			}
 		}
@@ -287,7 +287,7 @@ int main(int argc,char *argv[])
 #endif
 		/* ե륿 */
 		if (ftnum>0)
-			ftype=g_malloc(ftnum*sizeof(FTYPE));
+			ftype=g_malloc(ftnum*sizeof(FileType));
 		for (i=0;i<ftnum;i++) {
 			section=g_strdup_printf("filetype%04d",i);
 			ftype[i].ft_id=tcount++;
@@ -357,9 +357,9 @@ int main(int argc,char *argv[])
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].vline=FALSE;
 			/* ե */
-			if ((ftype[i].fontname
+			if ((ftype[i].font_name
 							=profile_get_string(profile,section,"font"))==NULL)
-				ftype[i].fontname=NULL;
+				ftype[i].font_name=NULL;
 			/*  */
 			if (!profile_get_value(profile,section,"color",
 								(gpointer)&ftype[i].color,sizeof(GdkColor)*12,
@@ -385,7 +385,7 @@ int main(int argc,char *argv[])
 	/* ե륿 */
 	if (ftnum<=0) {
 		ftnum=1;
-		ftype=g_malloc(ftnum*sizeof(FTYPE));
+		ftype=g_malloc(ftnum*sizeof(FileType));
 		ftype[0].text=g_strdup(_("All Files"));
 		ftype[0].ext=g_strdup("*");
 		ftype[0].margin=80;
@@ -404,7 +404,7 @@ int main(int argc,char *argv[])
 		ftype[0].uline=FALSE;
 		ftype[0].vline=FALSE;
 		/* ե */
-		ftype[0].fontname=NULL;
+		ftype[0].font_name=NULL;
 		/*  */
 		memcpy(ftype[0].color,system_color,sizeof(GdkColor)*12);
 	}
@@ -505,13 +505,13 @@ int main(int argc,char *argv[])
 	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
 	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
-	for (i=0;i<history && hisfile[i]!=NULL;i++) {
-		menu_item=gtk_menu_item_new_with_label(hisfile[i]);
+	for (i=0;i<history && history_files[i]!=NULL;i++) {
+		menu_item=gtk_menu_item_new_with_label(history_files[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"activate",
-					GTK_SIGNAL_FUNC(signal_activate_menu_history),hisfile[i]);
+			GTK_SIGNAL_FUNC(signal_activate_menu_history),history_files[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"destroy",
-					GTK_SIGNAL_FUNC(signal_destroy_menu_history),hisfile[i]);
-		gtk_object_set_user_data(GTK_OBJECT(menu_item),hisfile[i]);
+			GTK_SIGNAL_FUNC(signal_destroy_menu_history),history_files[i]);
+		gtk_object_set_user_data(GTK_OBJECT(menu_item),history_files[i]);
 		gtk_menu_insert(GTK_MENU(sub_menu),menu_item,i+MENUFILE-1);
 	}
 	if (i>0)
@@ -526,7 +526,7 @@ int main(int argc,char *argv[])
 	if (!second) {
 		for (i=1;i<argc;i++) {
 			if (arg_files[i-1]) {
-				arg=get_full_path(argv[i]);
+				arg=misc_get_full_path(argv[i]);
 				leng=strlen(arg)*sizeof(gchar);
 				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
 				memcpy(arg_text+length,arg,leng);
@@ -583,14 +583,14 @@ int main(int argc,char *argv[])
 	/* ɥ */
 	for (i=1;i<argc;i++)
 		if (arg_files[i-1]) {
-			ptw=open_edit_file(argv[i]);
+			tmaid=file_open_edit(argv[i]);
 			if (init_line!=0)	/* Ԥ˰ư */
-				jump_operation(ptw,init_line);
+				jump_operation(tmaid,init_line);
 			count++;
 		}
 	g_free(arg_files);
 	if (newfile && count<=0)
-		open_edit_file(NULL);
+		file_open_edit(NULL);
 
 	gtk_main();
 
@@ -610,19 +610,19 @@ int main(int argc,char *argv[])
 					(gpointer)&def_height,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"tmaid","n_pos",
 						(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT);
-		if (openpath!=NULL)
-			profile_set_value(profile,"tmaid","openpath",(gpointer)openpath,
-											(strlen(openpath)+1)*sizeof(gchar),
+		if (open_path!=NULL)
+			profile_set_value(profile,"tmaid","openpath",(gpointer)open_path,
+										(strlen(open_path)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
-		if (savepath!=NULL)
-			profile_set_value(profile,"tmaid","savepath",(gpointer)savepath,
-											(strlen(savepath)+1)*sizeof(gchar),
+		if (save_path!=NULL)
+			profile_set_value(profile,"tmaid","savepath",(gpointer)save_path,
+										(strlen(save_path)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 		/* ե */
-		for (i=0;i<history && hisfile[i]!=NULL;i++) {
+		for (i=0;i<history && history_files[i]!=NULL;i++) {
 			key=g_strdup_printf("history%d",i);
-			profile_set_value(profile,"tmaid",key,(gpointer)hisfile[i],
-										(strlen(hisfile[i])+1)*sizeof(gchar),
+			profile_set_value(profile,"tmaid",key,(gpointer)history_files[i],
+									(strlen(history_files[i])+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			g_free(key);
 		}
@@ -763,10 +763,10 @@ int main(int argc,char *argv[])
 									(gpointer)&ftype[i].vline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 			/* ե */
-			if (ftype[i].fontname!=NULL)
+			if (ftype[i].font_name!=NULL)
 				profile_set_value(profile,section,"font",
-								(gpointer)ftype[i].fontname,
-								(strlen(ftype[i].fontname)+1)*sizeof(gchar),
+								(gpointer)ftype[i].font_name,
+								(strlen(ftype[i].font_name)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			/*  */
 			profile_set_value(profile,section,"color",
@@ -781,8 +781,8 @@ int main(int argc,char *argv[])
 		profile_close(profile);
 	}
 	gdk_font_unref(system_font);
-	g_free(openpath);
-	g_free(savepath);
+	g_free(open_path);
+	g_free(save_path);
 	g_free(clipboard_text);
 #ifdef USE_GDKPIXBUF
 	g_free(printer.printer);
@@ -793,11 +793,11 @@ int main(int argc,char *argv[])
 	for (i=0;i<replace_num;i++)
 		g_free(replace_text[i]);
 	for (i=0;i<history;i++)
-		g_free(hisfile[i]);
+		g_free(history_files[i]);
 	for (i=0;i<ftnum;i++) {
 		g_free(ftype[i].text);
 		g_free(ftype[i].ext);
-		g_free(ftype[i].fontname);
+		g_free(ftype[i].font_name);
 	}
 	g_free(ftype);
 	return 0;
