@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include "charset.h"
-#include "other.h"
 #include "valchr.h"
+#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -38,7 +38,8 @@ static void valchr_dialog_changed(GtkWidget *widget,gpointer user_data)
 {
 	gint value;
 
-	strval(&value,gtk_entry_get_text(GTK_ENTRY(widget)),valchr_base,FALSE);
+	misc_str_to_val(&value,gtk_entry_get_text(GTK_ENTRY(widget)),
+															valchr_base,FALSE);
 	gtk_widget_set_sensitive(button0,0<=value && value<=255
 												&& charset->length[value]==1);
 }
@@ -50,9 +51,10 @@ static void valchr_dialog_clicked_radio(GtkWidget *widget,guint base)
 	gchar *text;
 	gint value;
 
-	strval(&value,gtk_entry_get_text(GTK_ENTRY(entry)),valchr_base,FALSE);
+	misc_str_to_val(&value,gtk_entry_get_text(GTK_ENTRY(entry)),
+															valchr_base,FALSE);
 	valchr_base=base;
-	text=valstr(value,valchr_base,0,FALSE);
+	text=misc_str_from_val(value,valchr_base,0,FALSE);
 	gtk_entry_set_text(GTK_ENTRY(entry),text);
 	g_free(text);
 }
@@ -63,7 +65,8 @@ static void valchr_dialog_clicked_ok(GtkWidget *widget,gchar *valchr)
 {
 	gint value;
 
-	strval(&value,gtk_entry_get_text(GTK_ENTRY(entry)),valchr_base,FALSE);
+	misc_str_to_val(&value,gtk_entry_get_text(GTK_ENTRY(entry)),
+															valchr_base,FALSE);
 	*valchr=valchr_default=valchr_default=value;
 	gtk_widget_destroy(dialog);
 	valchr_clicked_ok=TRUE;
@@ -75,7 +78,8 @@ static void valchr_dialog_activate(GtkWidget *widget,gchar *valchr)
 {
 	gint value;
 
-	strval(&value,gtk_entry_get_text(GTK_ENTRY(widget)),valchr_base,FALSE);
+	misc_str_to_val(&value,gtk_entry_get_text(GTK_ENTRY(widget)),
+															valchr_base,FALSE);
 	if (0<=value && value<=255 && charset->length[value]==1)
 		valchr_dialog_clicked_ok(widget,valchr);
 }
@@ -118,7 +122,7 @@ gboolean valchr_dialog(gchar *valchr)
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* ȥ꡼ */
 	entry=gtk_entry_new_with_max_length(4);
-	text=valstr(valchr_default,valchr_base,0,FALSE);
+	text=misc_str_from_val(valchr_default,valchr_base,0,FALSE);
 	gtk_entry_set_text(GTK_ENTRY(entry),text);
 	g_free(text);
 	gtk_signal_connect(GTK_OBJECT(entry),"activate",
